View source: R/071-api-lifecycle-0-9.R
| api_family_map | R Documentation |
Map exported APIs to conceptual families
api_family_map(inventory)
inventory |
API inventory or character names. |
A data frame containing exported APIs to conceptual families. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.