api_surface_summary: Summarise API surface by family and lifecycle status

View source: R/071-api-lifecycle-0-9.R

api_surface_summaryR Documentation

Summarise API surface by family and lifecycle status

Description

Summarise API surface by family and lifecycle status

Usage

api_surface_summary(inventory)

Arguments

inventory

Output of 'eye_api_inventory()' or compatible table.

Value

A data frame containing aPI surface by family and lifecycle status. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.

Related to api_surface_summary in eyeprocess...