View source: R/052-irt-validation-0-7.R
| as_irt_recovery_results | R Documentation |
Canonicalise parameter-recovery results
as_irt_recovery_results(results)
results |
Data frame with at least 'replicate', 'parameter', 'truth', and 'estimate'; optional 'lower', 'upper', 'converged', 'scenario', 'engine', and 'failure_type' columns are retained. |
A data frame containing canonicalise parameter-recovery results. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.