View source: R/066-process-decision-features-0-8.R
| assign_process_feature_family | R Documentation |
Assign features to conservative process-feature families
assign_process_feature_family(
feature_names,
registry = process_feature_family_registry()
)
feature_names |
Feature names. |
registry |
Feature-family registry. |
A vector or matrix containing assign features to conservative process-feature families, with shape determined by the supplied analysis units.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.