View source: R/052-irt-validation-0-7.R
| audit_convergence | R Documentation |
Audit convergence and classified failures
audit_convergence(results, minimum = 0.95, by = c("scenario", "engine"))
results |
Validation or model results. |
minimum |
Minimum acceptable value or threshold. |
by |
Grouping variables used when summarizing results. |
An object of class "eye_irt_convergence_audit", "data.frame", stored as a data frame, containing convergence and classified failures and associated metadata needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.