View source: R/052-irt-validation-0-7.R
| audit_coverage | R Documentation |
Audit coverage
audit_coverage(
results,
minimum = 0.9,
maximum = 1,
by = c("scenario", "engine", "parameter")
)
results |
Validation or model results. |
minimum |
Minimum acceptable value or threshold. |
maximum |
Maximum acceptable value or threshold. |
by |
Grouping variables used when summarizing results. |
An R object containing coverage. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.