View source: R/070-governed-pipelines-0-9.R
| audit_eye_pipeline | R Documentation |
Audit a pipeline definition or completed run
audit_eye_pipeline(x)
x |
Pipeline or pipeline run. |
An object of class "eye_pipeline_audit", stored as a named list, with components "table", "undeclared_decisions", "valid", "pipeline_hash". It contains a pipeline definition or completed run and associated metadata or diagnostics needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.