audit_frontier_model_contract: Audit whether a gated frontier model has a minimum evidence...

View source: R/065-frontier-gates-0-8.R

audit_frontier_model_contractR Documentation

Audit whether a gated frontier model has a minimum evidence contract

Description

Audit whether a gated frontier model has a minimum evidence contract

Usage

audit_frontier_model_contract(x, evidence = list())

Arguments

x

Gated model object.

evidence

Named evidence objects.

Value

A data frame containing whether a gated frontier model has a minimum evidence contract. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.