View source: R/052-irt-validation-0-7.R
| audit_interval_width | R Documentation |
Audit interval width
audit_interval_width(
results,
maximum = Inf,
by = c("scenario", "engine", "parameter")
)
results |
Validation or model results. |
maximum |
Maximum acceptable value or threshold. |
by |
Grouping variables used when summarizing results. |
An R object containing interval width. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.