audit_latent_distribution: Audit the empirical latent-trait distribution

View source: R/055-requested-api-completion-0-7.R

audit_latent_distributionR Documentation

Audit the empirical latent-trait distribution

Description

Audit the empirical latent-trait distribution

Usage

audit_latent_distribution(theta, tail_z = 3)

Arguments

theta

Numeric latent-trait draws/estimates.

tail_z

Absolute standardized threshold used for tail-rate diagnostics.

Value

A data frame containing the empirical latent-trait distribution. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.