View source: R/052-irt-validation-0-7.R
| audit_measurement_transportability | R Documentation |
Summarise measurement transportability across held-out groups
audit_measurement_transportability(
validation,
metric,
higher_is_better = TRUE,
max_range = NULL,
minimum = NULL,
maximum = NULL
)
validation |
Validation results or validation specification. |
metric |
Metric to calculate or audit. |
higher_is_better |
Whether larger metric values indicate better performance. |
max_range |
Maximum allowed range across held-out groups. |
minimum |
Minimum acceptable value or threshold. |
maximum |
Maximum acceptable value or threshold. |
An object of class "eye_measurement_transportability_audit", "data.frame", stored as a data frame, containing measurement transportability across held-out groups and associated metadata needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.