View source: R/058-process-preflight-governance-0-8.R
| audit_multivariate_process_quality | R Documentation |
Alias emphasizing data-quality interpretation of process anomaly auditing
audit_multivariate_process_quality(...)
... |
Additional arguments passed to the underlying method or helper. |
An R object containing alias emphasizing data-quality interpretation of process anomaly auditing. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.