audit_process_drift: Audit post-deployment psychometric and biometric drift

View source: R/059-deployment-drift-0-8.R

audit_process_driftR Documentation

Audit post-deployment psychometric and biometric drift

Description

Audit post-deployment psychometric and biometric drift

Usage

audit_process_drift(
  data,
  item = "item_id",
  batch = "deployment_batch",
  metrics = c("irt_difficulty", "irt_discrimination", "rt_ms", "dwell_ms", "pupil_bc",
    "valid_gaze_prop", "screen_luminance"),
  spec = process_drift_spec(),
  reference_batch = NULL,
  aggregate_fun = .ep08_mean
)

Arguments

data

Item-by-batch or trial-level deployment data.

item

Item identifier column.

batch

Ordered deployment batch/date column.

metrics

Numeric metrics to monitor.

spec

Drift specification.

reference_batch

Optional reference batch value(s).

aggregate_fun

Aggregation function used when multiple rows occur within item x batch.

Value

An object of class "eye_process_drift_audit", stored as a named list, with components "table", "trajectories", "item", "batch", "metrics", "spec", "reference_batch", "flag_columns", "caveat". It contains post-deployment psychometric and biometric drift and associated metadata or diagnostics needed to interpret the result.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.

Related to audit_process_drift in eyeprocess...