audit_process_window_sensitivity: Audit sensitivity of process summaries to temporal window...

View source: R/060-process-window-representations-0-8.R

audit_process_window_sensitivityR Documentation

Audit sensitivity of process summaries to temporal window choices

Description

Audit sensitivity of process summaries to temporal window choices

Usage

audit_process_window_sensitivity(
  data,
  widths_ms = c(250, 500, 1000, 1500),
  steps_ms = c(100, 250, 500),
  metric = "pupil_mean",
  grid = TRUE,
  ...
)

Arguments

data

Sample-level data.

widths_ms

Window widths.

steps_ms

Step widths; recycled or crossed depending on 'grid'.

metric

Extracted process metric to compare.

grid

If TRUE, evaluate all width-step combinations.

...

Passed to 'extract_process_windows()'.

Value

An object of class "eye_process_window_sensitivity", stored as a named list, with components "table", "metric", "settings", "caveat". It contains sensitivity of process summaries to temporal window choices and associated metadata or diagnostics needed to interpret the result.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.