audit_rmse: Audit rmse

View source: R/052-irt-validation-0-7.R

audit_rmseR Documentation

Audit rmse

Description

Audit rmse

Usage

audit_rmse(results, threshold = 0.3, by = c("scenario", "engine", "parameter"))

Arguments

results

Validation or model results.

threshold

Decision or diagnostic threshold.

by

Grouping variables used when summarizing results.

Value

An R object containing rmse. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.

Related to audit_rmse in eyeprocess...