audit_sbc: Audit SBC rank uniformity

View source: R/052-irt-validation-0-7.R

audit_sbcR Documentation

Audit SBC rank uniformity

Description

Uses binned chi-square diagnostics as a coarse screening diagnostic and also reports the mean/variance of normalized ranks. It is not a replacement for rank-histogram inspection.

Usage

audit_sbc(x, bins = 10L, alpha = 0.01)

Arguments

x

Object to print, plot, summarize, or audit.

bins

Number of bins used by the diagnostic.

alpha

Significance or tail-probability level.

Value

An object of class "eye_sbc_audit", "data.frame", stored as a data frame, containing sBC rank uniformity and associated metadata needed to interpret the result.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.

Related to audit_sbc in eyeprocess...