benchmark_memory_estimate: Memory estimate for an R object or generated problem size

View source: R/075-benchmark-stress-0-9.R

benchmark_memory_estimateR Documentation

Memory estimate for an R object or generated problem size

Description

Memory estimate for an R object or generated problem size

Usage

benchmark_memory_estimate(x, generator = NULL)

Arguments

x

Object, or numeric n when 'generator' is supplied.

generator

Optional function taking n.

Value

A data frame containing memory estimate for an R object or generated problem size. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.