benchmark_scaling_curve: Estimate scaling exponent from benchmark results

View source: R/075-benchmark-stress-0-9.R

benchmark_scaling_curveR Documentation

Estimate scaling exponent from benchmark results

Description

Estimate scaling exponent from benchmark results

Usage

benchmark_scaling_curve(x)

Arguments

x

Benchmark result.

Value

A data frame containing scaling exponent from benchmark results. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.