bind_process_windows: Bind compatible process-window objects

View source: R/060-process-window-representations-0-8.R

bind_process_windowsR Documentation

Bind compatible process-window objects

Description

Bind compatible process-window objects

Usage

bind_process_windows(...)

Arguments

...

Additional arguments passed to the underlying method or helper.

Value

An object of class "eye_process_windows", stored as a named list, with components "data", "spec", "source_n", "status". It contains bind compatible process-window objects and associated metadata or diagnostics needed to interpret the result.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.

Related to bind_process_windows in eyeprocess...