View source: R/074-process-registry-reliability-0-9.R
| bootstrap_process_reliability | R Documentation |
Bootstrap ICC reliability by resampling participants
bootstrap_process_reliability(
data,
person,
session,
measure,
replications = 500L,
seed = 1L
)
data |
Long data. |
person, session, measure |
Column names. |
replications |
Bootstrap replications. |
seed |
Seed. |
A data frame containing bootstrap ICC reliability by resampling participants. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.