View source: R/076-calibration-quality-uncertainty-0-9.R
| calibration_sensitivity_grid | R Documentation |
Sensitivity grid for deterministic calibration offsets
calibration_sensitivity_grid(
offset_x = c(-0.02, 0, 0.02),
offset_y = c(-0.02, 0, 0.02)
)
offset_x, offset_y |
Candidate offsets in coordinate units. |
A tabular R object containing sensitivity grid for deterministic calibration offsets; rows represent analysis units and columns contain the returned quantities.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.