View source: R/052-irt-validation-0-7.R
| calibration_transfer_audit | R Documentation |
Audit transfer of calibration across devices/sessions/sites
calibration_transfer_audit(data, group, observed, predicted)
data |
Data containing group, observed and predicted values. |
group |
Grouping column. |
observed |
Observed binary/numeric outcome column. |
predicted |
Predicted probability/numeric score column. |
An object of class "eye_calibration_transfer_audit", "data.frame", stored as a data frame, containing transfer of calibration across devices/sessions/sites and associated metadata needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.