compare_aoi_trajectories: Compare AOI trajectory feature objects

View source: R/060-process-window-representations-0-8.R

compare_aoi_trajectoriesR Documentation

Compare AOI trajectory feature objects

Description

Compare AOI trajectory feature objects

Usage

compare_aoi_trajectories(...)

Arguments

...

Additional arguments passed to the underlying method or helper.

Value

A data frame containing aOI trajectory feature objects. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.