compare_bayesian_process_models: Compare Bayesian process models by LOO or Bayes factor

View source: R/067-advanced-sensitivity-diagnostics-0-8.R

compare_bayesian_process_modelsR Documentation

Compare Bayesian process models by LOO or Bayes factor

Description

Compare Bayesian process models by LOO or Bayes factor

Usage

compare_bayesian_process_models(..., method = c("loo", "bayes_factor"))

Arguments

...

Fitted brms models.

method

'loo' or 'bayes_factor'.

Value

An R object containing bayesian process models by LOO or Bayes factor. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.