compare_decision_manifests: Compare two research decision manifests

View source: R/073-decision-manifests-0-9.R

compare_decision_manifestsR Documentation

Compare two research decision manifests

Description

Compare two research decision manifests

Usage

compare_decision_manifests(old, new)

Arguments

old

Earlier manifest.

new

Later manifest.

Value

An object of class "eye_decision_manifest_diff", "data.frame", stored as a data frame, containing two research decision manifests and associated metadata needed to interpret the result.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.