compare_deployment_batches: Compare two deployment batches descriptively

View source: R/059-deployment-drift-0-8.R

compare_deployment_batchesR Documentation

Compare two deployment batches descriptively

Description

Compare two deployment batches descriptively

Usage

compare_deployment_batches(
  data,
  batch = "deployment_batch",
  batch_a,
  batch_b,
  metrics = NULL,
  item = "item_id"
)

Arguments

data

Deployment data.

batch

Batch column.

batch_a, batch_b

Values to compare.

metrics

Metrics to compare.

item

Optional item identifier for item-matched differences.

Value

A data frame containing two deployment batches descriptively. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.