View source: R/076-calibration-quality-uncertainty-0-9.R
| compare_hard_probabilistic_aoi | R Documentation |
Compare hard and probabilistic AOI assignments
compare_hard_probabilistic_aoi(
data,
aois,
probabilistic,
x = "gaze_x",
y = "gaze_y"
)
data |
Gaze samples. |
aois |
Rectangular AOIs. |
probabilistic |
Probabilistic assignment object. |
x, y |
Gaze-coordinate columns. |
An R object containing hard and probabilistic AOI assignments. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.