compare_process_criterion_models: Compare process external-validity models

View source: R/062-context-process-structure-0-8.R

compare_process_criterion_modelsR Documentation

Compare process external-validity models

Description

Compare process external-validity models

Usage

compare_process_criterion_models(x)

Arguments

x

Object to process, inspect, compare, or plot.

Value

A data frame containing process external-validity models. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.