compare_raw_adjusted_pupil: Compare raw and confound-adjusted pupil values

View source: R/061-pupil-advanced-representations-0-8.R

compare_raw_adjusted_pupilR Documentation

Compare raw and confound-adjusted pupil values

Description

Compare raw and confound-adjusted pupil values

Usage

compare_raw_adjusted_pupil(x)

Arguments

x

Object to process, inspect, compare, or plot.

Value

A data frame containing raw and confound-adjusted pupil values. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.