View source: R/052-irt-validation-0-7.R
| compare_validation_engines | R Documentation |
Compare validation engines on common recovery output
compare_validation_engines(results)
results |
Validation or model results. |
An object of class "eye_validation_engine_comparison", "data.frame", stored as a data frame, containing validation engines on common recovery output and associated metadata needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.