compare_visual_context_irt: Compare base and visual-context IRT models

View source: R/062-context-process-structure-0-8.R

compare_visual_context_irtR Documentation

Compare base and visual-context IRT models

Description

Compare base and visual-context IRT models

Usage

compare_visual_context_irt(x)

Arguments

x

Object to process, inspect, compare, or plot.

Value

A data frame containing base and visual-context IRT models. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.