coverage_calibration_curve: Interval coverage calibration curve

View source: R/081-validation-extras-0-9.R

coverage_calibration_curveR Documentation

Interval coverage calibration curve

Description

Interval coverage calibration curve

Usage

coverage_calibration_curve(truth, lower, upper, nominal = NULL)

Arguments

truth

True values.

lower

Matrix/data.frame of lower limits or numeric vector.

upper

Matrix/data.frame of upper limits or numeric vector.

nominal

Nominal coverage labels, one per interval column.

Value

A data frame containing interval coverage calibration curve. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.