View source: R/076-calibration-quality-uncertainty-0-9.R
| data_quality_reporting_table | R Documentation |
Compact reporting table for eye-tracking data quality
data_quality_reporting_table(x)
x |
Data-quality profile. |
An R object containing compact reporting table for eye-tracking data quality. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.