decision_manifest_diff: Alias for manifest comparison emphasizing changed decision...

View source: R/073-decision-manifests-0-9.R

decision_manifest_diffR Documentation

Alias for manifest comparison emphasizing changed decision paths

Description

Alias for manifest comparison emphasizing changed decision paths

Usage

decision_manifest_diff(old, new)

Arguments

old

Earlier manifest.

new

Later manifest.

Value

An R object containing alias for manifest comparison emphasizing changed decision paths. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.