decision_manifest_hash: Stable hash of decision content

View source: R/073-decision-manifests-0-9.R

decision_manifest_hashR Documentation

Stable hash of decision content

Description

Stable hash of decision content

Usage

decision_manifest_hash(x)

Arguments

x

Manifest or decision object.

Value

An R object containing stable hash of decision content. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.