View source: R/073-decision-manifests-0-9.R
| decision_space_coverage | R Documentation |
Coverage of a declared decision space by evaluated specifications
decision_space_coverage(grid, evaluated)
grid |
Sensitivity grid. |
evaluated |
Sensitivity result or vector of evaluated specification IDs. |
A data frame containing coverage of a declared decision space by evaluated specifications. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.