detect_process_changepoint: Detect a response-process change point

View source: R/055-requested-api-completion-0-7.R

detect_process_changepointR Documentation

Detect a response-process change point

Description

Public roadmap alias for 'detect_irt_changepoints()'.

Usage

detect_process_changepoint(...)

Arguments

...

Additional arguments passed to the selected model, engine, or method.

Value

An R object containing a response-process change point. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.