View source: R/024-dynamic-irtree-engine.R
| dynamic_posterior_predictive_check | R Documentation |
Part of the research-scale validation, advanced-model, interoperability, storage, adapter, or reproducibility programme. Experimental model functions remain subject to declared evidence gates.
dynamic_posterior_predictive_check(object, draws = 200L, seed = 1L)
object |
Dynamic IRTree fit using the Stan engine. |
draws |
Maximum posterior predictive draws to summarize. |
seed |
Seed used when subsampling posterior draws. |
The documented eyeprocess object, data frame, plot, report path, or adapter result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.