event_roundtrip_audit: Audit event survival across an interchange round trip

View source: R/055-requested-api-completion-0-7.R

event_roundtrip_auditR Documentation

Audit event survival across an interchange round trip

Description

Audit event survival across an interchange round trip

Usage

event_roundtrip_audit(source_events, roundtrip_events, hed_column = NULL, ...)

Arguments

source_events, roundtrip_events

Event tables.

hed_column

Optional HED annotation column to compare structurally.

...

Arguments forwarded to 'event_semantics_audit()'.

Value

An object of class "eye_event_roundtrip_audit", stored as a named list, with components "status", "event_semantics", "hed". It contains event survival across an interchange round trip and associated metadata or diagnostics needed to interpret the result.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.