expand_eyeprocess_validation_plan: Expand a validation-evidence plan to a scenario table

View source: R/082-validation-evidence-programs-0-9.R

expand_eyeprocess_validation_planR Documentation

Expand a validation-evidence plan to a scenario table

Description

Expand a validation-evidence plan to a scenario table

Usage

expand_eyeprocess_validation_plan(x)

Arguments

x

Object to validate, summarize, verify, or otherwise process.

Value

An R object containing expand a validation-evidence plan to a scenario table. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.