export_eye_pipeline: Export a pipeline manifest and optional run status

View source: R/070-governed-pipelines-0-9.R

export_eye_pipelineR Documentation

Export a pipeline manifest and optional run status

Description

Export a pipeline manifest and optional run status

Usage

export_eye_pipeline(x, path)

Arguments

x

Pipeline or run.

path

CSV path.

Value

An R object containing a pipeline manifest and optional run status. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.

Related to export_eye_pipeline in eyeprocess...