View source: R/071-api-lifecycle-0-9.R
| eye_api_recommendation | R Documentation |
Lifecycle recommendation for API review
eye_api_recommendation(audit)
audit |
'eye_api_audit' object. |
A data frame containing lifecycle recommendation for API review. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.