View source: R/071-api-lifecycle-0-9.R
| eye_api_status | R Documentation |
Lookup lifecycle status for one or more APIs
eye_api_status(name, registry = eye_api_lifecycle())
name |
API names. |
registry |
Lifecycle registry. |
A data frame containing lookup lifecycle status for one or more APIs. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.