eye_benchmark_design: Define a computational benchmark design

View source: R/075-benchmark-stress-0-9.R

eye_benchmark_designR Documentation

Define a computational benchmark design

Description

Define a computational benchmark design

Usage

eye_benchmark_design(
  n_obs = c(10000, 1e+05, 1e+06),
  repetitions = 3L,
  label = "eyeprocess_scaling"
)

Arguments

n_obs

Observation counts.

repetitions

Repetitions per size.

label

Benchmark label.

Value

A tabular R object containing define a computational benchmark design; rows represent analysis units and columns contain the returned quantities.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.

Related to eye_benchmark_design in eyeprocess...