View source: R/070-governed-pipelines-0-9.R
| eye_pipeline_manifest | R Documentation |
Machine-readable pipeline manifest
eye_pipeline_manifest(x)
x |
Pipeline. |
A data frame containing machine-readable pipeline manifest. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.