eye_targets_manifest: Create a targets-compatible dependency manifest

View source: R/070-governed-pipelines-0-9.R

eye_targets_manifestR Documentation

Create a targets-compatible dependency manifest

Description

This function does not execute or silently translate arbitrary closures into a targets pipeline. It provides the dependency contract required to build an explicit '_targets.R' file.

Usage

eye_targets_manifest(x)

Arguments

x

Pipeline.

Value

A data frame containing a targets-compatible dependency manifest. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.

Related to eye_targets_manifest in eyeprocess...