View source: R/090-irt-multidimensional-cdm-0-9.R
| eyeprocess_cdm_attribute_profiles | R Documentation |
Enumerate latent attribute profiles
eyeprocess_cdm_attribute_profiles(
n_attributes,
attribute_names = paste0("A", seq_len(n_attributes))
)
n_attributes |
Number of cognitive-diagnosis attributes. |
attribute_names |
Optional names for the cognitive-diagnosis attributes. |
An R object containing enumerate latent attribute profiles. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.