View source: R/090-irt-multidimensional-cdm-0-9.R
| eyeprocess_cdm_classification_uncertainty | R Documentation |
Summarise CDM classification uncertainty from profile probabilities
eyeprocess_cdm_classification_uncertainty(profile_probabilities)
profile_probabilities |
Posterior attribute-profile probabilities. |
A data frame containing cDM classification uncertainty from profile probabilities. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.