View source: R/085-irt-scoring-adaptive-0-9.R
| eyeprocess_irt_adaptive_trace | R Documentation |
Create an auditable adaptive-testing trace
eyeprocess_irt_adaptive_trace(
item_id,
theta_before,
theta_after,
se_after,
information,
response = NA_real_
)
item_id |
Item identifier or vector of item identifiers. |
theta_before |
Latent-trait estimate before item administration. |
theta_after |
Latent-trait estimate after item administration. |
se_after |
Conditional standard error after item administration. |
information |
Item or test information value or vector. |
response |
Observed item response or response variable. |
An object of class "eye_irt_adaptive_trace", "data.frame", stored as a data frame, containing an auditable adaptive-testing trace and associated metadata needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.