View source: R/086-irt-linking-invariance-0-9.R
| eyeprocess_irt_anchor_audit | R Documentation |
Audit candidate anchor items using supplied DIF evidence
eyeprocess_irt_anchor_audit(
items,
dif = NULL,
max_abs_effect = 0.1,
min_information = NULL
)
items |
Item-parameter data frame or item collection. |
dif |
Differential-item-functioning evidence or summary. |
max_abs_effect |
Maximum permitted absolute effect for an anchor candidate. |
min_information |
Minimum required item information. |
A data frame containing candidate anchor items using supplied DIF evidence. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.