eyeprocess_irt_anchor_purification: Iteratively remove anchors exceeding a supplied effect...

View source: R/086-irt-linking-invariance-0-9.R

eyeprocess_irt_anchor_purificationR Documentation

Iteratively remove anchors exceeding a supplied effect threshold

Description

Iteratively remove anchors exceeding a supplied effect threshold

Usage

eyeprocess_irt_anchor_purification(
  items,
  effect_fun,
  initial = items$item_id,
  threshold = 0.1,
  max_iter = 10L
)

Arguments

items

Item-parameter data frame or item collection.

effect_fun

Function that computes the anchor-screening effect.

initial

Initial value, state, or anchor set.

threshold

Decision or diagnostic threshold.

max_iter

Maximum number of iterations.

Value

An object of class "eye_irt_anchor_purification", stored as a named list, with components "anchors", "history", "threshold". It contains iteratively remove anchors exceeding a supplied effect threshold and associated metadata or diagnostics needed to interpret the result.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.