eyeprocess_irt_apply_link: Apply linear IRT scale-linking coefficients

View source: R/086-irt-linking-invariance-0-9.R

eyeprocess_irt_apply_linkR Documentation

Description

Apply linear IRT scale-linking coefficients

Usage

eyeprocess_irt_apply_link(items, link)

Arguments

items

Item-parameter data frame or item collection.

link

IRT scale-linking coefficients or linking object.

Value

An R object containing linear IRT scale-linking coefficients. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.