eyeprocess_irt_classification_precision: Summarise decision precision at one or more theta cut scores

View source: R/093-irt-advanced-diagnostics-governance-0-9.R

eyeprocess_irt_classification_precisionR Documentation

Summarise decision precision at one or more theta cut scores

Description

Summarise decision precision at one or more theta cut scores

Usage

eyeprocess_irt_classification_precision(
  theta_estimate,
  standard_error,
  cut_score = 0,
  confidence = 0.95
)

Arguments

theta_estimate

Estimated latent-trait values.

standard_error

Standard errors corresponding to the estimates.

cut_score

Latent-scale classification cut score.

confidence

Requested confidence level.

Value

A tabular R object containing decision precision at one or more theta cut scores; rows represent analysis units and columns contain the returned quantities.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.