View source: R/086-irt-linking-invariance-0-9.R
| eyeprocess_irt_device_drift | R Documentation |
Summarise parameter drift across acquisition devices
eyeprocess_irt_device_drift(
parameters,
item_id = "item_id",
device = "device",
parameter = "b"
)
parameters |
Item-parameter data frame or parameter estimates. |
item_id |
Item identifier or vector of item identifiers. |
device |
Device identifier or grouping variable. |
parameter |
Name of the parameter to compare. |
A tabular R object containing parameter drift across acquisition devices; rows represent analysis units and columns contain the returned quantities.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.