View source: R/086-irt-linking-invariance-0-9.R
| eyeprocess_irt_dif_effect_curve | R Documentation |
Differential item functioning effect curve from two parameter sets
eyeprocess_irt_dif_effect_curve(
reference_item,
focal_item,
theta = seq(-4, 4, length.out = 81)
)
reference_item |
Reference-group item parameters. |
focal_item |
Focal-group item parameters. |
theta |
Latent-trait value or vector of latent-trait values. |
An object of class "eye_irt_dif_curve", "data.frame", stored as a data frame, containing differential item functioning effect curve from two parameter sets and associated metadata needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.