eyeprocess_irt_dtf_curve: Differential test functioning effect curve

View source: R/086-irt-linking-invariance-0-9.R

eyeprocess_irt_dtf_curveR Documentation

Differential test functioning effect curve

Description

Differential test functioning effect curve

Usage

eyeprocess_irt_dtf_curve(reference, focal, theta = seq(-4, 4, length.out = 81))

Arguments

reference

Reference-form or reference-group item parameters.

focal

Focal-form or focal-group item parameters.

theta

Latent-trait value or vector of latent-trait values.

Value

An object of class "eye_irt_dtf_curve", "data.frame", stored as a data frame, containing differential test functioning effect curve and associated metadata needed to interpret the result.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.