eyeprocess_irt_engine_evidence_table: Build an external-engine capability and availability table

View source: R/094-validation-paper-tables-atlas-0-9.R

eyeprocess_irt_engine_evidence_tableR Documentation

Build an external-engine capability and availability table

Description

Build an external-engine capability and availability table

Usage

eyeprocess_irt_engine_evidence_table()

Value

A data frame containing an external-engine capability and availability table. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.