View source: R/088-irt-engine-adapters-0-9.R
| eyeprocess_irt_engine_registry | R Documentation |
Registry of specialized external IRT engines
eyeprocess_irt_engine_registry()
An object of class "eye_irt_engine_registry", "data.frame", stored as a data frame, containing registry of specialized external IRT engines and associated metadata needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.