View source: R/088-irt-engine-adapters-0-9.R
| eyeprocess_irt_engine_status | R Documentation |
Query an external IRT engine
eyeprocess_irt_engine_status(engine)
engine |
Requested estimation or analysis engine. |
An object of class "eye_irt_engine_registry", "data.frame", stored as a data frame, containing query an external IRT engine and associated metadata needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.