eyeprocess_irt_expected_score: Expected item score

View source: R/083-irt-foundations-information-0-9.R

eyeprocess_irt_expected_scoreR Documentation

Expected item score

Description

Expected item score

Usage

eyeprocess_irt_expected_score(
  theta,
  family = c("2pl", "3pl", "4pl", "grm", "gpcm", "nominal"),
  ...
)

Arguments

theta

Latent-trait value or vector of latent-trait values.

family

IRT response family or model family.

...

Additional arguments passed to the selected method or external engine.

Value

A numeric value or vector containing expected item score.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.