View source: R/085-irt-scoring-adaptive-0-9.R
| eyeprocess_irt_exposure_summary | R Documentation |
Summarise item exposure rates
eyeprocess_irt_exposure_summary(
administered,
item_bank_ids = unique(administered)
)
administered |
Identifiers or records for administered items. |
item_bank_ids |
Complete set of item identifiers in the bank. |
A data frame containing item exposure rates. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.