eyeprocess_irt_extreme_score_audit: Audit extreme response scores without assigning behavioral...

View source: R/084-irt-diagnostics-0-9.R

eyeprocess_irt_extreme_score_auditR Documentation

Audit extreme response scores without assigning behavioral labels

Description

Audit extreme response scores without assigning behavioral labels

Usage

eyeprocess_irt_extreme_score_audit(
  responses,
  lower_fraction = 0.02,
  upper_fraction = 0.98
)

Arguments

responses

Response matrix or response data.

lower_fraction

Lower extreme-score fraction.

upper_fraction

Upper extreme-score fraction.

Value

A data frame containing extreme response scores without assigning behavioral labels. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.