View source: R/093-irt-advanced-diagnostics-governance-0-9.R
| eyeprocess_irt_infit_outfit | R Documentation |
These statistics summarize response-model residual behavior. They are not labels for motivation, misconduct, diagnosis, or respondent intent.
eyeprocess_irt_infit_outfit(
observed,
expected,
by = c("item", "person"),
min_variance = 1e-08
)
observed |
Observed responses or observed values. |
expected |
Model-expected probabilities or expected values. |
by |
Grouping variables or aggregation level. |
min_variance |
Minimum variance used to stabilize residual calculations. |
A data frame containing residual-based Infit and Outfit summaries. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.