View source: R/086-irt-linking-invariance-0-9.R
| eyeprocess_irt_invariance_evidence | R Documentation |
Combine invariance evidence without converting it to a binary validity claim
eyeprocess_irt_invariance_evidence(
anchor_audit = NULL,
dif = NULL,
dtf = NULL,
linking = NULL,
process_concordance = NULL
)
anchor_audit |
Anchor-item audit result. |
dif |
Differential-item-functioning evidence or summary. |
dtf |
Differential-test-functioning evidence or curve. |
linking |
Scale-linking evidence or result. |
process_concordance |
Process-DIF concordance evidence. |
An object of class "eye_irt_invariance_evidence", stored as a named list, with components "components", "present", "completeness", "interpretation". It contains combine invariance evidence without converting it to a binary validity claim and associated metadata or diagnostics needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.