View source: R/085-irt-scoring-adaptive-0-9.R
| eyeprocess_irt_item_bank | R Documentation |
Item bank object for adaptive design
eyeprocess_irt_item_bank(items, content = NULL, exposure_limit = 1)
items |
Item-parameter data frame or item collection. |
content |
Item content/category metadata. |
exposure_limit |
Maximum permitted item exposure. |
An object of class "eye_irt_item_bank", stored as a named list, with components "items", "exposure_limit". It contains item bank object for adaptive design and associated metadata or diagnostics needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.