View source: R/084-irt-diagnostics-0-9.R
| eyeprocess_irt_item_fit_residuals | R Documentation |
Compute item residual fit summaries from observed and predicted probabilities
eyeprocess_irt_item_fit_residuals(
responses,
probabilities,
item_ids = colnames(responses)
)
responses |
Response matrix or response data. |
probabilities |
Probability matrix or vector, with dimensions appropriate to the model. |
item_ids |
Optional item identifiers. |
An object of class "eye_irt_item_fit", "data.frame", stored as a data frame, containing item residual fit summaries from observed and predicted probabilities and associated metadata needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.