View source: R/083-irt-foundations-information-0-9.R
| eyeprocess_irt_item_information | R Documentation |
Compute item information for transparent IRT families
eyeprocess_irt_item_information(
theta,
family = c("2pl", "3pl", "4pl", "grm", "gpcm", "nominal"),
...,
D = 1
)
theta |
Latent-trait value or vector of latent-trait values. |
family |
IRT response family or model family. |
... |
Additional arguments passed to the selected method or external engine. |
D |
Logistic scaling constant. |
A numeric value or vector containing item information for transparent IRT families.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.