eyeprocess_irt_item_selection: Select the most informative eligible item at a theta estimate

View source: R/085-irt-scoring-adaptive-0-9.R

eyeprocess_irt_item_selectionR Documentation

Select the most informative eligible item at a theta estimate

Description

Select the most informative eligible item at a theta estimate

Usage

eyeprocess_irt_item_selection(
  bank,
  theta,
  administered = character(),
  exposure = NULL,
  content_required = NULL,
  D = 1
)

Arguments

bank

Validated item-bank object.

theta

Latent-trait value or vector of latent-trait values.

administered

Identifiers or records for administered items.

exposure

Item exposure information used by the adaptive-selection rule.

content_required

Content constraints required for item selection.

D

Logistic scaling constant.

Value

An object of class "eye_irt_item_selection", stored as a named list, with components "selected", "information", "theta", "reason", "candidate_count". It contains the most informative eligible item at a theta estimate and associated metadata or diagnostics needed to interpret the result.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.