View source: R/090-irt-multidimensional-cdm-0-9.R
| eyeprocess_irt_latent_regression_design | R Documentation |
Build a latent-regression design matrix with explicit centering metadata
eyeprocess_irt_latent_regression_design(data, formula, center_numeric = TRUE)
data |
Input data frame, matrix, or compatible analysis object. |
formula |
Model formula. |
center_numeric |
Whether numeric predictors are centered. |
An object of class "eye_irt_latent_regression_design", stored as a named list, with components "matrix", "formula", "centers", "complete". It contains a latent-regression design matrix with explicit centering metadata and associated metadata or diagnostics needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.