eyeprocess_irt_local_dependence_pairs: Extract high residual-dependence item pairs

View source: R/084-irt-diagnostics-0-9.R

eyeprocess_irt_local_dependence_pairsR Documentation

Extract high residual-dependence item pairs

Description

Extract high residual-dependence item pairs

Usage

eyeprocess_irt_local_dependence_pairs(q3, threshold = 0.2, absolute = TRUE)

Arguments

q3

Q3 residual-correlation matrix or summary.

threshold

Decision or diagnostic threshold.

absolute

Whether diagnostic thresholds apply to absolute values.

Value

A data frame containing high residual-dependence item pairs. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.