View source: R/083-irt-foundations-information-0-9.R
| eyeprocess_irt_measurement_precision_profile | R Documentation |
Summarise measurement precision across a theta region
eyeprocess_irt_measurement_precision_profile(
theta,
items,
target = c(-2, 2),
D = 1
)
theta |
Latent-trait value or vector of latent-trait values. |
items |
Item-parameter data frame or item collection. |
target |
Target level, distribution, or criterion. |
D |
Logistic scaling constant. |
An object of class "eye_irt_precision_profile", stored as a named list, with components "curve", "target", "area", "min_information", "max_sem". It contains measurement precision across a theta region and associated metadata or diagnostics needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.