View source: R/093-irt-advanced-diagnostics-governance-0-9.R
| eyeprocess_irt_missing_by_design_audit | R Documentation |
Audit missing-by-design structure in an IRT response matrix
eyeprocess_irt_missing_by_design_audit(
responses,
design = NULL,
min_administered = 1L
)
responses |
Response matrix or response data. |
design |
Validation or simulation design object. |
min_administered |
Minimum number of administered items required for a record. |
An object of class "eye_irt_missing_design_audit", stored as a named list, with components "n_persons", "n_items", "observed_fraction", "administered_per_person", "administered_per_item", "sparse_persons", "structural_missing", "unexpected_missing", "has_declared_design". It contains missing-by-design structure in an IRT response matrix and associated metadata or diagnostics needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.