View source: R/089-irt-validation-evidence-0-9.R
| eyeprocess_irt_misspecification_metrics | R Documentation |
Compare recovery under reference and misspecified scenarios
eyeprocess_irt_misspecification_metrics(
reference_summary,
misspecified_summary
)
reference_summary |
Reference-model validation summary. |
misspecified_summary |
Misspecified-model validation summary. |
An R object containing recovery under reference and misspecified scenarios. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.