View source: R/089-irt-validation-evidence-0-9.R
| eyeprocess_irt_misspecification_suite | R Documentation |
Create a model-misspecification suite
eyeprocess_irt_misspecification_suite()
A data frame containing a model-misspecification suite. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.