eyeprocess_irt_model_card_audit: Audit completeness of an IRT model card

View source: R/093-irt-advanced-diagnostics-governance-0-9.R

eyeprocess_irt_model_card_auditR Documentation

Audit completeness of an IRT model card

Description

Audit completeness of an IRT model card

Usage

eyeprocess_irt_model_card_audit(card)

Arguments

card

Value supplied for the card argument.

Value

A data frame containing completeness of an IRT model card. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.