eyeprocess_irt_monotonicity_audit: Audit monotonicity of an item response curve

View source: R/084-irt-diagnostics-0-9.R

eyeprocess_irt_monotonicity_auditR Documentation

Audit monotonicity of an item response curve

Description

Audit monotonicity of an item response curve

Usage

eyeprocess_irt_monotonicity_audit(theta, probability, tolerance = 1e-08)

Arguments

theta

Latent-trait value or vector of latent-trait values.

probability

Model-implied probability vector.

tolerance

Numerical or decision tolerance.

Value

An object of class "eye_irt_monotonicity_audit", stored as a named list, with components "monotone_non_decreasing", "n_decreases", "largest_decrease", "theta", "probability". It contains monotonicity of an item response curve and associated metadata or diagnostics needed to interpret the result.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.