View source: R/084-irt-diagnostics-0-9.R
| eyeprocess_irt_parameter_plausibility_audit | R Documentation |
Audit basic plausibility of dichotomous item parameters
eyeprocess_irt_parameter_plausibility_audit(
items,
discrimination = c(0.2, 4),
difficulty = c(-6, 6),
lower_asymptote = c(0, 0.5),
upper_asymptote = c(0.5, 1)
)
items |
Item-parameter data frame or item collection. |
discrimination |
Discrimination vector or matrix. |
difficulty |
Item difficulty or location parameter. |
lower_asymptote |
Lower-asymptote parameter values. |
upper_asymptote |
Upper-asymptote parameter values. |
A data frame containing basic plausibility of dichotomous item parameters. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.