eyeprocess_irt_person_fit_residuals: Compute person residual fit summaries

View source: R/084-irt-diagnostics-0-9.R

eyeprocess_irt_person_fit_residualsR Documentation

Compute person residual fit summaries

Description

Compute person residual fit summaries

Usage

eyeprocess_irt_person_fit_residuals(
  responses,
  probabilities,
  person_ids = rownames(responses)
)

Arguments

responses

Response matrix or response data.

probabilities

Probability matrix or vector, with dimensions appropriate to the model.

person_ids

Optional person identifiers.

Value

An object of class "eye_irt_person_fit", "data.frame", stored as a data frame, containing person residual fit summaries and associated metadata needed to interpret the result.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.