View source: R/089-irt-validation-evidence-0-9.R
| eyeprocess_irt_sbc_ranks | R Documentation |
Construct SBC ranks from scalar truths and posterior draws
eyeprocess_irt_sbc_ranks(truth, draws, randomize_ties = TRUE, seed = 1L)
truth |
Known simulated parameter value or vector of true values. |
draws |
Posterior draws, with draws arranged by simulation case as required. |
randomize_ties |
Whether ties in SBC ranks are randomized. |
seed |
Random-number seed for reproducible execution. |
A vector or matrix containing sBC ranks from scalar truths and posterior draws, with shape determined by the supplied analysis units.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.