eyeprocess_irt_score_table: Score a response matrix with EAP, MAP, or ML

View source: R/085-irt-scoring-adaptive-0-9.R

eyeprocess_irt_score_tableR Documentation

Score a response matrix with EAP, MAP, or ML

Description

Score a response matrix with EAP, MAP, or ML

Usage

eyeprocess_irt_score_table(
  responses,
  items,
  method = c("EAP", "MAP", "ML"),
  person_ids = rownames(responses),
  ...
)

Arguments

responses

Response matrix or response data.

items

Item-parameter data frame or item collection.

method

Scoring, linking, or analysis method.

person_ids

Optional person identifiers.

...

Additional arguments passed to the selected method or external engine.

Value

A tabular R object containing a response matrix with EAP, MAP, or ML; rows represent analysis units and columns contain the returned quantities.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.