eyeprocess_irt_test_information: Compute a test information curve from item parameters

View source: R/083-irt-foundations-information-0-9.R

eyeprocess_irt_test_informationR Documentation

Compute a test information curve from item parameters

Description

Compute a test information curve from item parameters

Usage

eyeprocess_irt_test_information(theta, items, D = 1)

Arguments

theta

Latent-trait value or vector of latent-trait values.

items

Item-parameter data frame or item collection.

D

Logistic scaling constant.

Value

An object of class "eye_irt_information_profile", "data.frame", stored as a data frame, containing a test information curve from item parameters and associated metadata needed to interpret the result.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.