eyeprocess_irt_testlet_spec: Declare a testlet structure for bifactor/two-tier IRT engines

View source: R/090-irt-multidimensional-cdm-0-9.R

eyeprocess_irt_testlet_specR Documentation

Declare a testlet structure for bifactor/two-tier IRT engines

Description

Declare a testlet structure for bifactor/two-tier IRT engines

Usage

eyeprocess_irt_testlet_spec(item_id, testlet, general_dimension = "general")

Arguments

item_id

Item identifier or vector of item identifiers.

testlet

Testlet membership identifier.

general_dimension

General dimension name or index.

Value

An object of class "eye_irt_testlet_spec", "data.frame", stored as a data frame, containing declare a testlet structure for bifactor/two-tier IRT engines and associated metadata needed to interpret the result.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.