View source: R/090-irt-multidimensional-cdm-0-9.R
| eyeprocess_mirt_loading_audit | R Documentation |
Audit multidimensional IRT loading coverage
eyeprocess_mirt_loading_audit(spec, min_items_per_dimension = 3L)
spec |
Model, validation, or analysis specification object. |
min_items_per_dimension |
Minimum number of items required per dimension. |
A data frame containing multidimensional IRT loading coverage. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.