View source: R/094-validation-paper-tables-atlas-0-9.R
| eyeprocess_negative_control_evidence_table | R Documentation |
Build a paper-ready negative-control table
eyeprocess_negative_control_evidence_table(x, digits = 4L)
x |
Object to validate, summarize, verify, or otherwise process. |
digits |
Number of decimal digits used for presentation. |
An R object containing a paper-ready negative-control table. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.