eyeprocess_process_item_profile: Aggregate process channels by item

View source: R/087-irt-process-joint-0-9.R

eyeprocess_process_item_profileR Documentation

Aggregate process channels by item

Description

Aggregate process channels by item

Usage

eyeprocess_process_item_profile(data, item, channels)

Arguments

data

Input data frame, matrix, or compatible analysis object.

item

Name of the item identifier column.

channels

Names or definitions of measurement channels.

Value

A tabular R object containing aggregate process channels by item; rows represent analysis units and columns contain the returned quantities.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.