View source: R/087-irt-process-joint-0-9.R
| eyeprocess_process_missingness_pattern | R Documentation |
Summarise missingness patterns across response and process channels
eyeprocess_process_missingness_pattern(data, response, channels)
data |
Input data frame, matrix, or compatible analysis object. |
response |
Observed item response or response variable. |
channels |
Names or definitions of measurement channels. |
A data frame containing missingness patterns across response and process channels. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.