eyeprocess_process_person_profile: Aggregate process channels by person

View source: R/087-irt-process-joint-0-9.R

eyeprocess_process_person_profileR Documentation

Aggregate process channels by person

Description

Aggregate process channels by person

Usage

eyeprocess_process_person_profile(data, person, channels)

Arguments

data

Input data frame, matrix, or compatible analysis object.

person

Name of the person identifier column.

channels

Names or definitions of measurement channels.

Value

A tabular R object containing aggregate process channels by person; rows represent analysis units and columns contain the returned quantities.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.