eyeprocess_validation_claim_matrix: Build a machine-readable validation claim/evidence matrix

View source: R/091-validation-stress-freeze-0-9.R

eyeprocess_validation_claim_matrixR Documentation

Build a machine-readable validation claim/evidence matrix

Description

Build a machine-readable validation claim/evidence matrix

Usage

eyeprocess_validation_claim_matrix(
  claim_id,
  claim,
  evidence_id,
  evidence_type,
  status = "qualified",
  boundary = NA_character_
)

Arguments

claim_id

Unique identifier for the claim.

claim

Text of the software-validation claim.

evidence_id

Identifier of evidence supporting or testing the claim.

evidence_type

Type or class of evidence.

status

Evidence, model, or governance status.

boundary

Explicit interpretation or scope boundary for the claim.

Value

A data frame containing a machine-readable validation claim/evidence matrix. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.