eyeprocess_validation_evidence_index: Create an index over frozen validation evidence artifacts

View source: R/094-validation-paper-tables-atlas-0-9.R

eyeprocess_validation_evidence_indexR Documentation

Create an index over frozen validation evidence artifacts

Description

Create an index over frozen validation evidence artifacts

Usage

eyeprocess_validation_evidence_index(root, recursive = TRUE)

Arguments

root

Root directory for evidence indexing.

recursive

Whether evidence files are indexed recursively.

Value

A data frame containing an index over frozen validation evidence artifacts. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.