View source: R/082-validation-evidence-programs-0-9.R
| eyeprocess_validation_evidence_grade | R Documentation |
Grade the completeness of validation evidence
eyeprocess_validation_evidence_grade(
components,
required = c("design", "execution", "summary", "provenance", "hash")
)
components |
Named evidence components. |
required |
Required evidence components or requirements. |
An object of class "eye_validation_evidence_grade", stored as a named list, with components "grade", "required", "present", "coverage". It contains grade the completeness of validation evidence and associated metadata or diagnostics needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.