View source: R/091-validation-stress-freeze-0-9.R
| eyeprocess_validation_evidence_manifest | R Documentation |
Create an evidence manifest from files and in-memory objects
eyeprocess_validation_evidence_manifest(
files = character(),
objects = list(),
source_commit = NA_character_,
label = "eyeprocess-0.9-m2"
)
files |
File paths to include in the evidence manifest. |
objects |
Objects to include in the evidence manifest. |
source_commit |
Source-control commit associated with the evidence. |
label |
Human-readable label. |
An object of class "eye_validation_evidence_manifest", stored as a named list, with components "label", "source_commit", "files", "objects", "generated_at". It contains an evidence manifest from files and in-memory objects and associated metadata or diagnostics needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.