file_hash_manifest: Build a file hash manifest

View source: R/078-reproducibility-provenance-0-9.R

file_hash_manifestR Documentation

Build a file hash manifest

Description

Build a file hash manifest

Usage

file_hash_manifest(paths, algorithm = c("md5", "sha256"))

Arguments

paths

File paths.

algorithm

Hash algorithm; currently 'md5' uses base R, 'sha256' uses openssl when available.

Value

A data frame containing a file hash manifest. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.

Related to file_hash_manifest in eyeprocess...