filter_pupil_signal: Filter pupil signal robustly

View source: R/061-pupil-advanced-representations-0-8.R

filter_pupil_signalR Documentation

Filter pupil signal robustly

Description

Filter pupil signal robustly

Usage

filter_pupil_signal(...)

Arguments

...

Additional arguments passed to the underlying method or helper.

Value

An R object containing filter pupil signal robustly. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.

Related to filter_pupil_signal in eyeprocess...