View source: R/074-process-registry-reliability-0-9.R
| find_process_measures | R Documentation |
Find process measures by channel, level, status, or text
find_process_measures(
registry = process_measure_registry(),
channel = NULL,
level = NULL,
status = NULL,
query = NULL
)
registry |
Registry. |
channel |
Optional channel filter. |
level |
Optional level pattern. |
status |
Optional status filter. |
query |
Optional text query. |
A tabular R object containing find process measures by channel, level, status, or text; rows represent analysis units and columns contain the returned quantities.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.