View source: R/051-advanced-process-irt-0-7.R
| fit_dynamic_gpirt | R Documentation |
Dynamic GPIRT external-engine gate
fit_dynamic_gpirt(data, external_engine = NULL, ...)
data |
Input data frame or compatible tabular object. |
external_engine |
Validated external fitting function. |
... |
Additional arguments passed to the selected model, engine, or method. |
An object of class "eye_dynamic_gpirt", stored as a named list, with components "model", "engine", "status". It contains dynamic GPIRT external-engine gate and associated metadata or diagnostics needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.