fit_eyeprocess_gdina: Fit a G-DINA cognitive-diagnosis model without fallback...

View source: R/088-irt-engine-adapters-0-9.R

fit_eyeprocess_gdinaR Documentation

Fit a G-DINA cognitive-diagnosis model without fallback substitution

Description

Fit a G-DINA cognitive-diagnosis model without fallback substitution

Usage

fit_eyeprocess_gdina(dat, Q, model = "GDINA", ..., engine = "GDINA")

Arguments

dat

Response data supplied to the GDINA engine.

Q

Binary item-by-attribute Q-matrix.

model

Model specification passed to the selected external engine.

...

Additional arguments passed to the selected method or external engine.

engine

Requested estimation or analysis engine.

Value

An object of class "eye_external_irt_fit", stored as a named list, with components "status", "engine", "fit", "call". It contains a G-DINA cognitive-diagnosis model without fallback substitution and associated metadata or diagnostics needed to interpret the result.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.

Related to fit_eyeprocess_gdina in eyeprocess...