fit_eyeprocess_tam: Fit a TAM model without substituting another estimator

View source: R/088-irt-engine-adapters-0-9.R

fit_eyeprocess_tamR Documentation

Fit a TAM model without substituting another estimator

Description

Fit a TAM model without substituting another estimator

Usage

fit_eyeprocess_tam(
  resp,
  model = c("rasch", "2pl", "gpcm"),
  ...,
  engine = "TAM"
)

Arguments

resp

Response matrix supplied to TAM.

model

Model specification passed to the selected external engine.

...

Additional arguments passed to the selected method or external engine.

engine

Requested estimation or analysis engine.

Value

An object of class "eye_external_irt_fit", stored as a named list, with components "status", "engine", "fit", "call". It contains a TAM model without substituting another estimator and associated metadata or diagnostics needed to interpret the result.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.

Related to fit_eyeprocess_tam in eyeprocess...