fit_flow_mirt: Flow-MIRT external-engine gate

View source: R/051-advanced-process-irt-0-7.R

fit_flow_mirtR Documentation

Flow-MIRT external-engine gate

Description

Flow-MIRT external-engine gate

Usage

fit_flow_mirt(response_matrix, external_engine = NULL, ...)

Arguments

response_matrix

Person-by-item response matrix.

external_engine

Validated external fitting function.

...

Additional arguments passed to the selected model, engine, or method.

Value

An object of class "eye_flow_mirt", stored as a named list, with components "model", "status", "engine". It contains flow-MIRT external-engine gate and associated metadata or diagnostics needed to interpret the result.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.

Related to fit_flow_mirt in eyeprocess...