View source: R/027-strategy-diffusion-engines.R View source: R/022-advanced-models-v2.R
| fit_gaze_diffusion_irt | R Documentation |
Part of the research-scale validation, advanced-model, interoperability, storage, adapter, or reproducibility programme. Experimental model functions remain subject to declared evidence gates.
fit_gaze_diffusion_irt(data, spec = gaze_diffusion_spec(), seed = 1L, ...)
data |
Trial-level data. |
spec |
Diffusion specification. |
seed |
Seed. |
... |
Engine arguments. |
The documented eyeprocess object, data frame, plot, report path, or adapter result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.