View source: R/051-advanced-process-irt-0-7.R
| fit_variational_irt | R Documentation |
Variational IRT external-engine gate
fit_variational_irt(response_matrix, external_engine = NULL, ...)
response_matrix |
Person-by-item response matrix. |
external_engine |
Validated external fitting function. |
... |
Additional arguments passed to the selected model, engine, or method. |
An object of class "eye_variational_irt", stored as a named list, with components "model", "status", "engine". It contains variational IRT external-engine gate and associated metadata or diagnostics needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.