View source: R/076-calibration-quality-uncertainty-0-9.R
| fixation_boundary_uncertainty | R Documentation |
Distance to nearest rectangular AOI boundary
fixation_boundary_uncertainty(data, aois, x = "gaze_x", y = "gaze_y")
data |
Gaze samples. |
aois |
Rectangular AOIs. |
x, y |
Coordinates. |
A tabular R object containing distance to nearest rectangular AOI boundary; rows represent analysis units and columns contain the returned quantities.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.