freeze_eyeprocess_validation_atlas: Freeze a validation atlas with a reproducibility fingerprint

View source: R/094-validation-paper-tables-atlas-0-9.R

freeze_eyeprocess_validation_atlasR Documentation

Freeze a validation atlas with a reproducibility fingerprint

Description

Freeze a validation atlas with a reproducibility fingerprint

Usage

freeze_eyeprocess_validation_atlas(atlas, metadata = list())

Arguments

atlas

Validation-evidence atlas object.

metadata

Named metadata to store with the frozen object.

Value

An object of class "eye_validation_atlas_freeze", stored as a named list, with components "payload", "hash", "frozen". It contains freeze a validation atlas with a reproducibility fingerprint and associated metadata or diagnostics needed to interpret the result.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.