freeze_software_paper_evidence: Freeze software-paper evidence to an RDS with a hash

View source: R/079-software-paper-evidence-0-9.R

freeze_software_paper_evidenceR Documentation

Freeze software-paper evidence to an RDS with a hash

Description

Freeze software-paper evidence to an RDS with a hash

Usage

freeze_software_paper_evidence(x, path)

Arguments

x

Evidence bundle.

path

Output path.

Value

A data frame containing freeze software-paper evidence to an RDS with a hash. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.