gaze_anchored_3pl_alignment: Return the process-alignment table from a gaze-anchored 3PL...

View source: R/068-bayesian-3pl-process-diagnostics-0-8.R

gaze_anchored_3pl_alignmentR Documentation

Return the process-alignment table from a gaze-anchored 3PL audit

Description

Return the process-alignment table from a gaze-anchored 3PL audit

Usage

gaze_anchored_3pl_alignment(x)

Arguments

x

An 'eye_gaze_anchored_3pl_audit'.

Value

An R object containing return the process-alignment table from a gaze-anchored 3PL audit. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.