View source: R/076-calibration-quality-uncertainty-0-9.R
| gaze_uncertainty_ellipse | R Documentation |
Uncertainty ellipse implied by an empirical calibration-error model
gaze_uncertainty_ellipse(model, level = 0.95, center = NULL)
model |
Calibration error model. |
level |
Probability level. |
center |
Optional center; defaults to model mean error. |
A data frame containing uncertainty ellipse implied by an empirical calibration-error model. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.