get_irt_model: Retrieve a registered multimodal IRT model

View source: R/049-multimodal-irt-registry.R

get_irt_modelR Documentation

Retrieve a registered multimodal IRT model

Description

Retrieve a registered multimodal IRT model

Usage

get_irt_model(id)

Arguments

id

Stable identifier.

Value

An R object containing retrieve a registered multimodal IRT model. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.

Related to get_irt_model in eyeprocess...