View source: R/062-context-process-structure-0-8.R
| incremental_process_validity | R Documentation |
Extract incremental process validity
incremental_process_validity(x)
x |
Object to process, inspect, compare, or plot. |
A data frame containing incremental process validity. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.