inject_aoi_label_noise: Inject AOI label noise

View source: R/075-benchmark-stress-0-9.R

inject_aoi_label_noiseR Documentation

Inject AOI label noise

Description

Inject AOI label noise

Usage

inject_aoi_label_noise(data, aoi = "aoi", proportion, seed = 1L)

Arguments

data

Data.

aoi

AOI label column.

proportion

Proportion reassigned to another observed label.

seed

Seed.

Value

An R object containing inject AOI label noise. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.