inject_device_shift: Inject an additive device/site shift in a numeric feature

View source: R/075-benchmark-stress-0-9.R

inject_device_shiftR Documentation

Inject an additive device/site shift in a numeric feature

Description

Inject an additive device/site shift in a numeric feature

Usage

inject_device_shift(data, column, shift, rows = NULL)

Arguments

data

Data.

column

Numeric column.

shift

Additive shift.

rows

Optional logical/index rows affected.

Value

An R object containing inject an additive device/site shift in a numeric feature. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.

Related to inject_device_shift in eyeprocess...