View source: R/075-benchmark-stress-0-9.R
| inject_pupil_dropout | R Documentation |
Inject pupil dropout
inject_pupil_dropout(data, pupil = "pupil", proportion, seed = 1L)
data |
Data. |
pupil |
Pupil column. |
proportion |
Dropout proportion. |
seed |
Seed. |
An R object containing inject pupil dropout. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.