inject_sampling_jitter: Inject timestamp jitter

View source: R/075-benchmark-stress-0-9.R

inject_sampling_jitterR Documentation

Inject timestamp jitter

Description

Inject timestamp jitter

Usage

inject_sampling_jitter(data, time = "timestamp_ms", sd, seed = 1L)

Arguments

data

Data.

time

Timestamp column.

sd

Jitter standard deviation in timestamp units.

seed

Seed.

Value

An R object containing inject timestamp jitter. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.