View source: R/052-irt-validation-0-7.R
| irt_validation_spec | R Documentation |
Creates an evidence contract rather than executing a particular estimator. The object can be passed to stress-test and evidence-grading helpers.
irt_validation_spec(
model_id,
replications = 250L,
parameters = NULL,
metrics = c("bias", "rmse", "coverage", "interval_width", "convergence"),
grouped_validation = c("device", "session", "site"),
preprocessing_variants = NULL,
misspecification_scenarios = NULL,
thresholds = list(max_abs_bias = 0.1, max_rmse = 0.3, min_coverage = 0.9,
max_failure_rate = 0.05, min_external_folds = 2L),
seed = 20260808L,
notes = NULL
)
model_id |
Stable model identifier. |
replications |
Number of simulation replications planned. |
parameters |
Parameter families expected to be recovered. |
metrics |
Recovery metrics to require. |
grouped_validation |
Grouping variables for transport validation. |
preprocessing_variants |
Optional named preprocessing variants. |
misspecification_scenarios |
Optional named scenarios. |
thresholds |
Named evidence thresholds. |
seed |
Reproducibility seed. |
notes |
Free-text scientific notes. |
An object of class "eye_irt_validation_spec", stored as a named list, with components "model_id", "replications", "parameters", "metrics", "grouped_validation", "preprocessing_variants", "misspecification_scenarios", "thresholds", "seed", "notes", "contract_version", "created_with". It contains specify a validation programme for a process-IRT model and associated metadata or diagnostics needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.