View source: R/052-irt-validation-0-7.R
| leave_device_out_validation | R Documentation |
Leave device out validation
leave_device_out_validation(data, device, fitter, predictor, scorer)
data |
Input data frame or compatible tabular object. |
device |
Device identifier or device facet. |
fitter |
Model-fitting function. |
predictor |
Prediction function. |
scorer |
Function that scores predictions. |
An object of class "eye_leave_device_out_validation", "data.frame", stored as a data frame, containing leave device out validation and associated metadata needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.