View source: R/052-irt-validation-0-7.R
| leave_session_out_validation | R Documentation |
Leave session out validation
leave_session_out_validation(data, session, fitter, predictor, scorer)
data |
Input data frame or compatible tabular object. |
session |
Session identifier or session facet. |
fitter |
Model-fitting function. |
predictor |
Prediction function. |
scorer |
Function that scores predictions. |
An object of class "eye_leave_session_out_validation", "data.frame", stored as a data frame, containing leave session out validation and associated metadata needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.