View source: R/052-irt-validation-0-7.R
| leave_site_out_validation | R Documentation |
Leave site out validation
leave_site_out_validation(data, site, fitter, predictor, scorer)
data |
Input data frame or compatible tabular object. |
site |
Site identifier or site facet. |
fitter |
Model-fitting function. |
predictor |
Prediction function. |
scorer |
Function that scores predictions. |
An object of class "eye_leave_site_out_validation", "data.frame", stored as a data frame, containing leave site out validation and associated metadata needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.