View source: R/049-multimodal-irt-registry.R
| list_irt_models | R Documentation |
List registered multimodal IRT models
list_irt_models()
A tabular R object containing list registered multimodal IRT models; rows represent analysis units and columns contain the returned quantities.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.