lock_decision_manifest: Lock a decision manifest by content hash

View source: R/073-decision-manifests-0-9.R

lock_decision_manifestR Documentation

Lock a decision manifest by content hash

Description

Lock a decision manifest by content hash

Usage

lock_decision_manifest(x, label = "analysis_decisions")

Arguments

x

Manifest.

label

Optional lock label.

Value

An object of class "eye_decision_manifest_lock", stored as a named list, with components "manifest", "manifest_hash", "label", "locked_at", "status". It contains lock a decision manifest by content hash and associated metadata or diagnostics needed to interpret the result.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.