View source: R/081-validation-extras-0-9.R
| measurement_error_budget | R Documentation |
Build a non-collapsed measurement-error budget
measurement_error_budget(
accuracy = NA_real_,
precision = NA_real_,
data_loss = NA_real_,
effective_hz = NA_real_,
calibration_drift = NA_real_,
units = NULL
)
accuracy |
Measurement inaccuracy/offset metric. |
precision |
Measurement imprecision metric. |
data_loss |
Data-loss proportion. |
effective_hz |
Effective sampling frequency. |
calibration_drift |
Optional drift metric. |
units |
Optional named units. |
A data frame containing a non-collapsed measurement-error budget. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.