multimodal_m2_process_information: Quantify response-target process information in the M0-M2...

View source: R/102-multimodal-m2-evidence-0-10.R

multimodal_m2_process_informationR Documentation

Quantify response-target process information in the M0-M2 sequence

Description

Computes two complementary quantities on a common response target: response-target PSIS-LOO ELPD and posterior variance of person ability. This avoids simply summing channel Fisher information under a joint correlated model.

Usage

multimodal_m2_process_information(x)

Arguments

x

An 'eye_multimodal_m2_ablation'.

Value

An 'eye_multimodal_m2_information'.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.