object_hash: Hash an R object reproducibly within an R serialization...

View source: R/078-reproducibility-provenance-0-9.R

object_hashR Documentation

Hash an R object reproducibly within an R serialization version

Description

Hash an R object reproducibly within an R serialization version

Usage

object_hash(x)

Arguments

x

R object.

Value

An R object containing hash an R object reproducibly within an R serialization version. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.

Related to object_hash in eyeprocess...