outcome_blind_feature_audit: Audit whether candidate predictors can be constructed without...

View source: R/077-negative-controls-leakage-0-9.R

outcome_blind_feature_auditR Documentation

Audit whether candidate predictors can be constructed without an outcome column

Description

Audit whether candidate predictors can be constructed without an outcome column

Usage

outcome_blind_feature_audit(data, outcome, feature_fun)

Arguments

data

Data frame.

outcome

Outcome column name.

feature_fun

Function receiving outcome-hidden data and returning features.

Value

A named list with components "status", "outcome", "feature_result", "error", "warnings", "input_columns", "interpretation", containing whether candidate predictors can be constructed without an outcome column and associated metadata or diagnostics.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.