partition_eye_storage: Create a partition specification

View source: R/028-api-storage-adapters.R

partition_eye_storageR Documentation

Create a partition specification

Description

Part of the research-scale validation, advanced-model, interoperability, storage, adapter, or reproducibility programme. Experimental model functions remain subject to declared evidence gates.

Usage

partition_eye_storage(by = c("participant_id", "session_id", "recording_id"),
  format = c("parquet", "csv", "rds"), compression = "zstd", max_rows = 1000000L)

Arguments

by

Partition columns.

format

Storage format.

compression

Compression codec for Parquet.

max_rows

Maximum rows per physical file.

Value

The documented eyeprocess object, data frame, plot, report path, or adapter result.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.