pipeline_failures: Return failed pipeline steps

View source: R/070-governed-pipelines-0-9.R

pipeline_failuresR Documentation

Return failed pipeline steps

Description

Return failed pipeline steps

Usage

pipeline_failures(x)

Arguments

x

Pipeline run.

Value

A data frame containing return failed pipeline steps. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.

Related to pipeline_failures in eyeprocess...