pipeline_result: Extract a pipeline result by step name

View source: R/070-governed-pipelines-0-9.R

pipeline_resultR Documentation

Extract a pipeline result by step name

Description

Extract a pipeline result by step name

Usage

pipeline_result(x, step)

Arguments

x

Pipeline run.

step

Step name.

Value

An R object containing a pipeline result by step name. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.

Related to pipeline_result in eyeprocess...