pipeline_step_status: Pipeline step status table

View source: R/070-governed-pipelines-0-9.R

pipeline_step_statusR Documentation

Pipeline step status table

Description

Pipeline step status table

Usage

pipeline_step_status(x)

Arguments

x

Pipeline run.

Value

A data frame containing pipeline step status table. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.

Related to pipeline_step_status in eyeprocess...