plot.eye_adapter_regression_audit: Plot eye adapter regression audit

View source: R/056-completion-plots-0-7.R

plot.eye_adapter_regression_auditR Documentation

Plot eye adapter regression audit

Description

Plot eye adapter regression audit

Usage

## S3 method for class 'eye_adapter_regression_audit'
plot(x, ...)

Arguments

x

Object to print, plot, summarize, or audit.

...

Additional arguments passed to the selected model, engine, or method.

Value

Invisibly returns the plotting result when available; the primary effect is drawing plot eye adapter regression audit.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.