View source: R/048-semantic-validation-0-7.R
| plot.eye_compatibility_evidence_matrix | R Documentation |
Plot detailed compatibility evidence
## S3 method for class 'eye_compatibility_evidence_matrix'
plot(x, ...)
x |
Object to print, plot, summarize, or audit. |
... |
Additional arguments passed to the selected model, engine, or method. |
Invisibly returns the plotting result when available; the primary effect is drawing plot detailed compatibility evidence.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.