S3 method supporting a research-scale eyeprocess object.
Usage
# S3 method for class 'eye_dynamic_irtree'
plot(x, type = c("observed", "fitted", "residual"), ...)
Arguments
- x
Value for `x`. See the function description and relevant article for constraints.
- type
Value for `type`. See the function description and relevant article for constraints.
- ...
Additional arguments passed to the selected engine or method.
Value
The documented eyeprocess object, data frame, plot, report path, or adapter result.