plot.eye_event_time_irt: Plot eye event time irt

View source: R/056-completion-plots-0-7.R

plot.eye_event_time_irtR Documentation

Plot eye event time irt

Description

Plot eye event time irt

Usage

## S3 method for class 'eye_event_time_irt'
plot(x, ...)

Arguments

x

Object to print, plot, summarize, or audit.

...

Additional arguments passed to the selected model, engine, or method.

Value

Invisibly returns the plotting result when available; the primary effect is drawing plot eye event time irt.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.