plot.eye_functional_pupil_sensitivity: plot eye functional pupil sensitivity

View source: R/026-functional-pupil-engine.R

plot.eye_functional_pupil_sensitivityR Documentation

plot eye functional pupil sensitivity

Description

S3 method supporting a research-scale eyeprocess object.

Usage

## S3 method for class 'eye_functional_pupil_sensitivity'
plot(x, parameter = NULL, ...)

Arguments

x

Value for 'x'. See the function description and relevant article for constraints.

parameter

Value for 'parameter'. See the function description and relevant article for constraints.

...

Additional arguments passed to the selected engine or method.

Value

The documented eyeprocess object, data frame, plot, report path, or adapter result.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.