plot.eye_gaze_informed_missingness_irt: Plot eye gaze informed missingness irt

View source: R/056-completion-plots-0-7.R

plot.eye_gaze_informed_missingness_irtR Documentation

Plot eye gaze informed missingness irt

Description

Plot eye gaze informed missingness irt

Usage

## S3 method for class 'eye_gaze_informed_missingness_irt'
plot(x, ...)

Arguments

x

Object to print, plot, summarize, or audit.

...

Additional arguments passed to the selected model, engine, or method.

Value

Invisibly returns the plotting result when available; the primary effect is drawing plot eye gaze informed missingness irt.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.