plot.eye_model_promotion_audit: plot eye model promotion audit

View source: R/023-validation-orchestration.R

plot.eye_model_promotion_auditR Documentation

plot eye model promotion audit

Description

S3 method supporting a research-scale eyeprocess object.

Usage

## S3 method for class 'eye_model_promotion_audit'
plot(x, ...)

Arguments

x

Value for 'x'. See the function description and relevant article for constraints.

...

Additional arguments passed to the selected engine or method.

Value

The documented eyeprocess object, data frame, plot, report path, or adapter result.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.