plot.eye_nonparametric_rasch_audit: Plot nonparametric rasch audit diagnostics

View source: R/067-advanced-sensitivity-diagnostics-0-8.R

plot.eye_nonparametric_rasch_auditR Documentation

Plot nonparametric rasch audit diagnostics

Description

Plot nonparametric rasch audit diagnostics

Usage

## S3 method for class 'eye_nonparametric_rasch_audit'
plot(x, method = names(x$tests)[1L], ...)

Arguments

x

Object to process, inspect, compare, or plot.

method

Method used for the requested diagnostic or summary.

...

Additional arguments passed to the underlying method or helper.

Value

Invisibly returns the plotting result when available; the primary effect is drawing plot nonparametric rasch audit diagnostics.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.