View source: R/064-next-generation-plots-0-8.R
| plot.eye_pupil_fatigue_drift | R Documentation |
Plot pupil fatigue drift diagnostics
## S3 method for class 'eye_pupil_fatigue_drift'
plot(x, ...)
x |
Object to process, inspect, compare, or plot. |
... |
Additional arguments passed to the underlying method or helper. |
Invisibly returns the plotting result when available; the primary effect is drawing plot pupil fatigue drift diagnostics.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.