View source: R/028-api-storage-adapters.R
| plot.eye_storage_benchmark | R Documentation |
S3 method supporting a research-scale eyeprocess object.
## S3 method for class 'eye_storage_benchmark'
plot(x, metric = c("write_seconds", "read_seconds",
"bytes"), ...)
x |
Value for 'x'. See the function description and relevant article for constraints. |
metric |
Value for 'metric'. See the function description and relevant article for constraints. |
... |
Additional arguments passed to the selected engine or method. |
The documented eyeprocess object, data frame, plot, report path, or adapter result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.