plot.eye_vendor_compatibility_matrix: plot eye vendor compatibility matrix

View source: R/025-vendor-corpus.R

plot.eye_vendor_compatibility_matrixR Documentation

plot eye vendor compatibility matrix

Description

S3 method supporting a research-scale eyeprocess object.

Usage

## S3 method for class 'eye_vendor_compatibility_matrix'
plot(x, ...)

Arguments

x

Value for 'x'. See the function description and relevant article for constraints.

...

Additional arguments passed to the selected engine or method.

Value

The documented eyeprocess object, data frame, plot, report path, or adapter result.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.