plot_process_changepoint: Plot detected process change points

View source: R/055-requested-api-completion-0-7.R

plot_process_changepointR Documentation

Plot detected process change points

Description

Plot detected process change points

Usage

plot_process_changepoint(object, ...)

Arguments

object

An 'eye_irt_changepoints', 'eye_changepoint_rt_irt', or 'eye_changepoint_multimodal_irt' object.

...

Graphical arguments.

Value

An R object containing plot detected process change points. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.