plot_pupil_components: Plot tonic/phasic pupil components

View source: R/064-next-generation-plots-0-8.R

plot_pupil_componentsR Documentation

Plot tonic/phasic pupil components

Description

Plot tonic/phasic pupil components

Usage

plot_pupil_components(
  data,
  time = "time_ms",
  smoothed = "pupil_smoothed",
  tonic = "pupil_tonic",
  phasic = "pupil_phasic",
  ...
)

Arguments

data

Data frame containing the required process variables.

time

Time values or name of the time variable.

smoothed

Name of the smoothed pupil-signal column.

tonic

Name of the tonic pupil-component column.

phasic

Name of the phasic pupil-component column.

...

Additional arguments passed to the underlying method or helper.

Value

A tabular R object containing plot tonic/phasic pupil components; rows represent analysis units and columns contain the returned quantities.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.