plot_pupil_preprocessing_audit: Plot raw-to-processed pupil preprocessing stages

View source: R/064-next-generation-plots-0-8.R

plot_pupil_preprocessing_auditR Documentation

Plot raw-to-processed pupil preprocessing stages

Description

Plot raw-to-processed pupil preprocessing stages

Usage

plot_pupil_preprocessing_audit(
  data,
  time = "time_ms",
  signals = c("pupil_raw", "pupil_interpolated", "pupil_smoothed", "pupil_bc"),
  ...
)

Arguments

data

Sample-level data.

time

Time column.

signals

Signal columns to overlay.

...

Additional arguments passed to the underlying method or helper.

Value

A tabular R object containing plot raw-to-processed pupil preprocessing stages; rows represent analysis units and columns contain the returned quantities.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.