plot_pupil_spectrum: Plot a pupil-signal power spectrum

View source: R/064-next-generation-plots-0-8.R

plot_pupil_spectrumR Documentation

Plot a pupil-signal power spectrum

Description

Plot a pupil-signal power spectrum

Usage

plot_pupil_spectrum(signal, sampling_rate_hz, max_hz = sampling_rate_hz/2, ...)

Arguments

signal

Numeric pupil signal.

sampling_rate_hz

Sampling rate.

max_hz

Maximum frequency shown; defaults to Nyquist.

...

Additional arguments passed to the underlying method or helper.

Value

A data frame containing plot a pupil-signal power spectrum. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.

Related to plot_pupil_spectrum in eyeprocess...