plot_validation_runtime: Plot validation runtime

View source: R/023-validation-orchestration.R

plot_validation_runtimeR Documentation

Plot validation runtime

Description

Part of the research-scale validation, advanced-model, interoperability, storage, adapter, or reproducibility programme. Experimental model functions remain subject to declared evidence gates.

Usage

plot_validation_runtime(x, engine = c("auto", "ggplot2", "base"), ...)

Arguments

x

Validation collection or job table.

engine

Plot engine.

...

Additional plotting arguments.

Value

The documented eyeprocess object, data frame, plot, report path, or adapter result.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.