View source: R/052-irt-validation-0-7.R
| posterior_predictive_discrepancies | R Documentation |
Posterior predictive discrepancy table
posterior_predictive_discrepancies(
observed,
replicated,
discrepancies = list(mean = function(x) mean(x, na.rm = TRUE), sd = function(x)
stats::sd(x, na.rm = TRUE), zero_rate = function(x) mean(x == 0, na.rm = TRUE))
)
observed |
Observed vector/data object. |
replicated |
List of replicated datasets, or matrix with one replicate per row. |
discrepancies |
Named list of functions mapping a dataset to one number. |
An object of class "eye_irt_ppc", "data.frame", stored as a data frame, containing posterior predictive discrepancy table and associated metadata needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.