predict.eye_censored_normal_process_irt: Predict expected bounded response from a censored-normal...

View source: R/054-additional-process-measurement-0-7.R

predict.eye_censored_normal_process_irtR Documentation

Predict expected bounded response from a censored-normal process IRT fit

Description

Predict expected bounded response from a censored-normal process IRT fit

Usage

## S3 method for class 'eye_censored_normal_process_irt'
predict(object, theta = object$theta, items = NULL, ...)

Arguments

object

A fitted eyeprocess model or audit object.

theta

Latent-trait values.

items

Items to include.

...

Additional arguments passed to the selected model, engine, or method.

Value

A vector or matrix containing expected bounded response from a censored-normal process IRT fit, with shape determined by the supplied analysis units.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.