predict_aoi_trajectory: Predict from an AOI growth curve

View source: R/060-process-window-representations-0-8.R

predict_aoi_trajectoryR Documentation

Predict from an AOI growth curve

Description

Predict from an AOI growth curve

Usage

predict_aoi_trajectory(object, time = NULL)

Arguments

object

Object supplied to the S3 method.

time

Time values or name of the time variable.

Value

A data frame containing from an AOI growth curve. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.