predict_item_parameter_priors: Predict pre-pilot item-parameter priors

View source: R/062-context-process-structure-0-8.R

predict_item_parameter_priorsR Documentation

Predict pre-pilot item-parameter priors

Description

Predict pre-pilot item-parameter priors

Usage

predict_item_parameter_priors(object, newdata)

Arguments

object

Seed model.

newdata

Candidate item feature data.

Value

An R object containing pre-pilot item-parameter priors. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.