predict_theta_at_time: Predict a latent trait at arbitrary times

View source: R/051-advanced-process-irt-0-7.R

predict_theta_at_timeR Documentation

Predict a latent trait at arbitrary times

Description

Predict a latent trait at arbitrary times

Usage

predict_theta_at_time(object, time)

Arguments

object

A fitted eyeprocess model or audit object.

time

Time values.

Value

An R object containing a latent trait at arbitrary times. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.