print.eye_diffusion_identification_study: print eye diffusion identification study

View source: R/027-strategy-diffusion-engines.R

print.eye_diffusion_identification_studyR Documentation

print eye diffusion identification study

Description

S3 method supporting a research-scale eyeprocess object.

Usage

## S3 method for class 'eye_diffusion_identification_study'
print(x, ...)

Arguments

x

Value for 'x'. See the function description and relevant article for constraints.

...

Additional arguments passed to the selected engine or method.

Value

The documented eyeprocess object, data frame, plot, report path, or adapter result.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.