View source: R/026-functional-pupil-engine.R
| print.eye_functional_scalar_comparison | R Documentation |
S3 method supporting a research-scale eyeprocess object.
## S3 method for class 'eye_functional_scalar_comparison'
print(x, ...)
x |
Value for 'x'. See the function description and relevant article for constraints. |
... |
Additional arguments passed to the selected engine or method. |
The documented eyeprocess object, data frame, plot, report path, or adapter result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.