print.eye_irt_model_spec: Print a multimodal IRT model specification

View source: R/049-multimodal-irt-registry.R

print.eye_irt_model_specR Documentation

Print a multimodal IRT model specification

Description

Print a multimodal IRT model specification

Usage

## S3 method for class 'eye_irt_model_spec'
print(x, ...)

Arguments

x

Object to print, plot, summarize, or audit.

...

Additional arguments passed to the selected model, engine, or method.

Value

Invisibly returns the input object after printing its summary; the object's class and contents are unchanged.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.