print.eye_redaction_result: print eye redaction result

View source: R/025-vendor-corpus.R

print.eye_redaction_resultR Documentation

print eye redaction result

Description

S3 method supporting a research-scale eyeprocess object.

Usage

## S3 method for class 'eye_redaction_result'
print(x, ...)

Arguments

x

Value for 'x'. See the function description and relevant article for constraints.

...

Additional arguments passed to the selected engine or method.

Value

The documented eyeprocess object, data frame, plot, report path, or adapter result.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.