print.eye_transition_design: print eye transition design

View source: R/024-dynamic-irtree-engine.R

print.eye_transition_designR Documentation

print eye transition design

Description

S3 method supporting a research-scale eyeprocess object.

Usage

## S3 method for class 'eye_transition_design'
print(x, ...)

Arguments

x

Value for 'x'. See the function description and relevant article for constraints.

...

Additional arguments passed to the selected engine or method.

Value

The documented eyeprocess object, data frame, plot, report path, or adapter result.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.