Skip to contents

S3 method supporting a research-scale eyeprocess object.

Usage

# S3 method for class 'eye_validation_run'
print(x, ...)

Arguments

x

Value for `x`. See the function description and relevant article for constraints.

...

Additional arguments passed to the selected engine or method.

Value

The documented eyeprocess object, data frame, plot, report path, or adapter result.