process_anomaly_distance: Extract multivariate process anomaly distances

View source: R/058-process-preflight-governance-0-8.R

process_anomaly_distanceR Documentation

Extract multivariate process anomaly distances

Description

Extract multivariate process anomaly distances

Usage

process_anomaly_distance(x)

Arguments

x

Object to process, inspect, compare, or plot.

Value

An R object containing multivariate process anomaly distances. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.