process_dif_nuisance_surrogate: Construct a process-data nuisance surrogate for DIF analysis

View source: R/051-advanced-process-irt-0-7.R

process_dif_nuisance_surrogateR Documentation

Construct a process-data nuisance surrogate for DIF analysis

Description

Construct a process-data nuisance surrogate for DIF analysis

Usage

process_dif_nuisance_surrogate(
  data,
  process_features,
  person = "participant_id",
  aggregate = TRUE
)

Arguments

data

Input data frame or compatible tabular object.

process_features

Names of process-derived features.

person

Person or participant identifier column.

aggregate

Aggregation rule for process features.

Value

A data frame containing a process-data nuisance surrogate for DIF analysis. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.