process_feature_family_registry: Registry of process-feature families and interpretation...

View source: R/066-process-decision-features-0-8.R

process_feature_family_registryR Documentation

Registry of process-feature families and interpretation guardrails

Description

Registry of process-feature families and interpretation guardrails

Usage

process_feature_family_registry()

Value

A data frame containing registry of process-feature families and interpretation guardrails. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.