process_feature_stability: Summarize process-feature stability across repeated analyses

View source: R/066-process-decision-features-0-8.R

process_feature_stabilityR Documentation

Summarize process-feature stability across repeated analyses

Description

Summarize process-feature stability across repeated analyses

Usage

process_feature_stability(
  data,
  feature = "feature",
  split = "split",
  importance = "importance",
  top_n = 20L
)

Arguments

data

Long table containing feature names and ranks/importance values.

feature

Feature column.

split

Split/resample column.

importance

Importance column, where larger is better.

top_n

Number of top features counted per split.

Value

A data frame containing process-feature stability across repeated analyses. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.