process_icc: Absolute-agreement ICC(A,1) for repeated process measures

View source: R/074-process-registry-reliability-0-9.R

process_iccR Documentation

Absolute-agreement ICC(A,1) for repeated process measures

Description

Absolute-agreement ICC(A,1) for repeated process measures

Usage

process_icc(data, person, session, measure)

Arguments

data

Long data.

person

Participant column.

session

Session/repetition column.

measure

Measure column.

Value

A data frame containing absolute-agreement ICC(A,1) for repeated process measures. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.

Related to process_icc in eyeprocess...