View source: R/074-process-registry-reliability-0-9.R
| process_measure_coverage | R Documentation |
Process-measure coverage for an observed dataset
process_measure_coverage(data, registry = process_measure_registry())
data |
Data frame. |
registry |
Registry. |
A data frame containing process-measure coverage for an observed dataset. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.