View source: R/074-process-registry-reliability-0-9.R
| process_measure_registry | R Documentation |
Unified process-measure registry
process_measure_registry(include_experimental = TRUE)
include_experimental |
Include experimental registry entries. |
A data frame containing unified process-measure registry. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.