process_negative_control_permute: Permutation negative control

View source: R/077-negative-controls-leakage-0-9.R

process_negative_control_permuteR Documentation

Permutation negative control

Description

Permutation negative control

Usage

process_negative_control_permute(data, outcome, seed = 1L, within = NULL)

Arguments

data

Data frame.

outcome

Outcome column.

seed

Random seed.

within

Optional grouping columns within which to permute.

Value

An R object containing permutation negative control. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.