process_negative_control_shift: Temporal-shift negative control

View source: R/077-negative-controls-leakage-0-9.R

process_negative_control_shiftR Documentation

Temporal-shift negative control

Description

Temporal-shift negative control

Usage

process_negative_control_shift(data, column, lag = 1L, by = NULL)

Arguments

data

Data frame.

column

Column to shift.

lag

Number of rows to shift within each group.

by

Optional grouping columns.

Value

An R object containing temporal-shift negative control. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.