View source: R/051-advanced-process-irt-0-7.R
| process_state_transition_summary | R Documentation |
Summarize HMM process-state transitions
process_state_transition_summary(object)
object |
A fitted eyeprocess model or audit object. |
A data frame containing hMM process-state transitions. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.