propagate_calibration_uncertainty: Propagate empirical calibration uncertainty around gaze...

View source: R/076-calibration-quality-uncertainty-0-9.R

propagate_calibration_uncertaintyR Documentation

Propagate empirical calibration uncertainty around gaze samples

Description

Propagate empirical calibration uncertainty around gaze samples

Usage

propagate_calibration_uncertainty(
  data,
  model,
  x = "gaze_x",
  y = "gaze_y",
  draws = 500L,
  seed = 1L
)

Arguments

data

Gaze samples.

model

Calibration error model.

x, y

Gaze-coordinate columns.

draws

Monte Carlo draws per sample.

seed

Seed.

Value

An R object containing propagate empirical calibration uncertainty around gaze samples. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.