provenance_edge_table: Build a provenance edge table

View source: R/078-reproducibility-provenance-0-9.R

provenance_edge_tableR Documentation

Build a provenance edge table

Description

Build a provenance edge table

Usage

provenance_edge_table(from, to, relation = "wasDerivedFrom")

Arguments

from, to

Node identifiers.

relation

PROV-like relation labels.

Value

A data frame containing a provenance edge table. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.