provenance_lineage_table: Build a provenance lineage node table

View source: R/078-reproducibility-provenance-0-9.R

provenance_lineage_tableR Documentation

Build a provenance lineage node table

Description

Build a provenance lineage node table

Usage

provenance_lineage_table(
  id,
  type = "entity",
  label = id,
  value = NA_character_
)

Arguments

id

Node identifiers.

type

Node types such as entity, activity, agent.

label

Human-readable labels.

value

Optional values/locations.

Value

A data frame containing a provenance lineage node table. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.