View source: R/048-semantic-validation-0-7.R
| public_validation_corpus | R Documentation |
Returns conservative metadata only. The package deliberately does not auto-download third-party human-participant data; users must review the source licence/terms and obtain data from the authoritative repository.
public_validation_corpus()
A data frame containing public validation-corpus registry. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.