read_api_lifecycle_registry: Read API lifecycle registry from CSV

View source: R/071-api-lifecycle-0-9.R

read_api_lifecycle_registryR Documentation

Read API lifecycle registry from CSV

Description

Read API lifecycle registry from CSV

Usage

read_api_lifecycle_registry(path)

Arguments

path

CSV path.

Value

An R object containing aPI lifecycle registry from CSV. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.