View source: R/091-validation-stress-freeze-0-9.R
| read_eyeprocess_validation_evidence | R Documentation |
Read and verify a frozen evidence bundle
read_eyeprocess_validation_evidence(path, verify = TRUE)
path |
File path for reading or writing. |
verify |
Whether integrity verification is performed when reading. |
An R object containing and verify a frozen evidence bundle. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.