read_reproducibility_fingerprint: Read a reproducibility fingerprint

View source: R/078-reproducibility-provenance-0-9.R

read_reproducibility_fingerprintR Documentation

Read a reproducibility fingerprint

Description

Read a reproducibility fingerprint

Usage

read_reproducibility_fingerprint(path, format = NULL)

Arguments

path

Input path.

format

Optional format.

Value

An R object containing a reproducibility fingerprint. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.