read_validation_scenario_manifest: Read a validation scenario manifest

View source: R/082-validation-evidence-programs-0-9.R

read_validation_scenario_manifestR Documentation

Read a validation scenario manifest

Description

Read a validation scenario manifest

Usage

read_validation_scenario_manifest(path)

Arguments

path

File path for reading or writing.

Value

An R object containing a validation scenario manifest. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.