recalibrate_after_changepoint: Iteratively detect, clean, and recalibrate after process...

View source: R/050-process-irt-models-0-7.R

recalibrate_after_changepointR Documentation

Iteratively detect, clean, and recalibrate after process change points

Description

Iteratively detect, clean, and recalibrate after process change points

Usage

recalibrate_after_changepoint(
  data,
  fitter,
  person = "participant_id",
  order = "item_order",
  policy = c("flag", "exclude_post_change", "add_regime"),
  ...
)

Arguments

data

Input data frame or compatible tabular object.

fitter

Function accepting a data frame and returning a calibration fit.

person

Person or participant identifier column.

order

Within-sequence ordering variable.

policy

'flag', 'exclude_post_change', or 'add_regime'.

...

Additional arguments passed to the selected model, engine, or method.

Value

An object of class "eye_changepoint_recalibration", stored as a named list, with components "changepoints", "data", "fit", "policy". It contains iteratively detect, clean, and recalibrate after process change points and associated metadata or diagnostics needed to interpret the result.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.