register_eye_api_status: Add or update API lifecycle metadata without global mutation

View source: R/071-api-lifecycle-0-9.R

register_eye_api_statusR Documentation

Add or update API lifecycle metadata without global mutation

Description

Add or update API lifecycle metadata without global mutation

Usage

register_eye_api_status(
  registry = eye_api_lifecycle(),
  name,
  status,
  canonical = NA_character_,
  replacement = NA_character_,
  since = "0.9.0.9000",
  notes = NA_character_
)

Arguments

registry

Existing lifecycle registry.

name

API name.

status

Lifecycle status.

canonical

Canonical API for the same concept, if applicable.

replacement

Replacement for deprecated/superseded API.

since

Version in which status applies.

notes

Notes.

Value

An R object containing add or update API lifecycle metadata without global mutation. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.