register_irt_model: Register a multimodal IRT model

View source: R/049-multimodal-irt-registry.R

register_irt_modelR Documentation

Register a multimodal IRT model

Description

Register a multimodal IRT model

Usage

register_irt_model(spec, overwrite = FALSE)

Arguments

spec

An 'irt_model_spec()'.

overwrite

Whether to replace an existing model with the same id.

Value

An R object containing a multimodal IRT model. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.

Related to register_irt_model in eyeprocess...