View source: R/074-process-registry-reliability-0-9.R
| register_process_measure | R Documentation |
Add a process measure to a registry without global mutation
register_process_measure(
registry = process_measure_registry(),
name,
channel,
unit,
level,
interpretation,
guardrail,
status = "user_defined"
)
registry |
Registry. |
name, channel, unit, level, interpretation, guardrail, status |
Measure metadata. |
A tabular R object containing add a process measure to a registry without global mutation; rows represent analysis units and columns contain the returned quantities.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.