View source: R/070-governed-pipelines-0-9.R
| resume_eye_pipeline | R Documentation |
Resume a governed pipeline from a prior run
resume_eye_pipeline(x, previous, context = list(), stop_on_error = TRUE)
x |
Pipeline. |
previous |
Prior pipeline run. |
context |
Context used for new steps. |
stop_on_error |
Stop on non-optional error. |
An object of class "eye_pipeline_run", stored as a named list, with components "pipeline", "pipeline_hash", "outputs", "records", "errors", "warnings", "context_hash", "completed", "created_at", "status". It contains resume a governed pipeline from a prior run and associated metadata or diagnostics needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.