run_eyeprocess_mirtcat: Run a mirtCAT adaptive-testing workflow without fallback...

View source: R/088-irt-engine-adapters-0-9.R

run_eyeprocess_mirtcatR Documentation

Run a mirtCAT adaptive-testing workflow without fallback substitution

Description

Run a mirtCAT adaptive-testing workflow without fallback substitution

Usage

run_eyeprocess_mirtcat(..., engine = "mirtCAT")

Arguments

...

Additional arguments passed to the selected method or external engine.

engine

Requested estimation or analysis engine.

Value

An object of class "eye_external_irt_fit", stored as a named list, with components "status", "engine", "fit", "call". It contains a mirtCAT adaptive-testing workflow without fallback substitution and associated metadata or diagnostics needed to interpret the result.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.