run_eyeprocess_stress_evidence: Execute a declared measurement-stress evidence plan

View source: R/091-validation-stress-freeze-0-9.R

run_eyeprocess_stress_evidenceR Documentation

Execute a declared measurement-stress evidence plan

Description

'corruptors' is a named list of functions accepting '(data, severity, seed)'. 'metric_fun' must return a named finite/numeric vector (NA is allowed for metrics that are undefined in a scenario). The executor records software behavior under declared corruptions and does not define universal data- quality thresholds.

Usage

run_eyeprocess_stress_evidence(data, plan, corruptors, metric_fun)

Arguments

data

Input data frame, matrix, or compatible analysis object.

plan

Validation or stress-evidence plan object.

corruptors

Named list of corruption functions used by the stress programme.

metric_fun

Function used to compute the stress-programme evaluation metric.

Value

An object of class "eye_stress_evidence_result", stored as a named list, with components "plan", "scenarios", "baseline", "results", "failures", "guardrail". It contains execute a declared measurement-stress evidence plan and associated metadata or diagnostics needed to interpret the result.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.