View source: R/021-validation-program.R
| run_model_validation | R Documentation |
The fitter may return a model or throw an error. The extractor must return a data frame with 'parameter', 'estimate', and optionally 'std_error', 'lower', and 'upper'. The truth extractor must return a named numeric vector.
run_model_validation(
simulator,
fitter,
extractor,
truth_extractor,
grid = NULL,
spec = model_validation_spec(),
seed = 1L,
continue_on_error = TRUE
)
simulator |
Simulation function. |
fitter |
Estimation function receiving the simulation result. |
extractor |
Parameter extraction function. |
truth_extractor |
Truth extraction function. |
grid |
Scenario grid. |
spec |
Validation specification. |
seed |
Random seed. |
continue_on_error |
Record rather than stop on estimation errors. |
An 'eye_model_validation' object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.