View source: R/081-validation-extras-0-9.R
| sbc_ecdf_deviation | R Documentation |
ECDF deviation summary for SBC ranks
sbc_ecdf_deviation(x, n_draws = NULL)
x |
SBC diagnostics or ranks. |
n_draws |
Required if x is ranks. |
An R object containing eCDF deviation summary for SBC ranks. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.