score_partial_response_pattern: Score a partial response pattern from a calibrated mirt model

View source: R/063-operational-validation-0-8.R

score_partial_response_patternR Documentation

Score a partial response pattern from a calibrated mirt model

Description

Score a partial response pattern from a calibrated mirt model

Usage

score_partial_response_pattern(
  model,
  response_pattern,
  method = c("MAP", "EAP"),
  ...
)

Arguments

model

Calibrated 'mirt' model.

response_pattern

Full-length response vector with future/unobserved items as NA.

method

mirt scoring method, typically MAP or EAP.

...

Passed to 'mirt::fscores()'.

Value

A data frame containing a partial response pattern from a calibrated mirt model. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.