sensitivity_branch_fingerprint: Stable fingerprint of a sensitivity branch

View source: R/072-sensitivity-multiverse-0-9.R

sensitivity_branch_fingerprintR Documentation

Stable fingerprint of a sensitivity branch

Description

Stable fingerprint of a sensitivity branch

Usage

sensitivity_branch_fingerprint(specification)

Arguments

specification

One-row specification table or named list.

Value

An R object containing stable fingerprint of a sensitivity branch. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.