View source: R/072-sensitivity-multiverse-0-9.R
| sensitivity_multiverse_manifest | R Documentation |
Machine-readable multiverse manifest
sensitivity_multiverse_manifest(x)
x |
Sensitivity result. |
A data frame containing machine-readable multiverse manifest. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.