simulate_from_model: Simulate data from a model or registered model specification

View source: R/055-requested-api-completion-0-7.R

simulate_from_modelR Documentation

Simulate data from a model or registered model specification

Description

Simulate data from a model or registered model specification

Usage

simulate_from_model(model, ...)

Arguments

model

Registered model id/specification, simulation function, or an object exposing a 'simulate_fun' function.

...

Arguments passed to the simulator.

Value

An R object containing data from a model or registered model specification. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.

Related to simulate_from_model in eyeprocess...