View source: R/079-software-paper-evidence-0-9.R
| software_paper_coverage | R Documentation |
Compute descriptive evidence coverage
software_paper_coverage(x, supported = c("supported", "qualified"))
x |
Evidence bundle or claim matrix. |
supported |
Status labels counted as covered. |
A data frame containing descriptive evidence coverage. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.