software_paper_validation_table: Summarise validation evidence for a software paper

View source: R/079-software-paper-evidence-0-9.R

software_paper_validation_tableR Documentation

Summarise validation evidence for a software paper

Description

Summarise validation evidence for a software paper

Usage

software_paper_validation_table(x)

Arguments

x

Validation result/evidence matrix/table.

Value

An R object containing validation evidence for a software paper. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.