strategy_label_switching_diagnostics: Diagnose label stability across multiple starts

View source: R/027-strategy-diffusion-engines.R

strategy_label_switching_diagnosticsR Documentation

Diagnose label stability across multiple starts

Description

Part of the research-scale validation, advanced-model, interoperability, storage, adapter, or reproducibility programme. Experimental model functions remain subject to declared evidence gates.

Usage

strategy_label_switching_diagnostics(object, tolerance = 1e-4)

Arguments

object

Strategy fit.

tolerance

Log-likelihood tolerance for equivalent starts.

Value

The documented eyeprocess object, data frame, plot, report path, or adapter result.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.