streaming_score_history: Extract streaming score history

View source: R/063-operational-validation-0-8.R

streaming_score_historyR Documentation

Extract streaming score history

Description

Extract streaming score history

Usage

streaming_score_history(x)

Arguments

x

Object to process, inspect, compare, or plot.

Value

An R object containing streaming score history. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.