stress_test_local_dependence: Stress test local dependence

View source: R/052-irt-validation-0-7.R

stress_test_local_dependenceR Documentation

Stress test local dependence

Description

Stress test local dependence

Usage

stress_test_local_dependence(
  runner,
  strengths = c(0, 0.2, 0.5, 0.8),
  replications = 50L,
  seed = 20260808L
)

Arguments

runner

Function that executes one stress-test scenario.

strengths

Local-dependence strengths to evaluate.

replications

Number of simulation or validation replications.

seed

Random-number seed.

Value

An object of class "eye_irt_stress_test", "data.frame", stored as a data frame, containing stress test local dependence and associated metadata needed to interpret the result.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.