stress_test_preprocessing: Stress test preprocessing

View source: R/052-irt-validation-0-7.R

stress_test_preprocessingR Documentation

Stress test preprocessing

Description

Stress test preprocessing

Usage

stress_test_preprocessing(
  runner,
  variants,
  replications = 25L,
  seed = 20260808L
)

Arguments

runner

Function that executes one stress-test scenario.

variants

Preprocessing variants to evaluate.

replications

Number of simulation or validation replications.

seed

Random-number seed.

Value

An object of class "eye_irt_stress_test", "data.frame", stored as a data frame, containing stress test preprocessing and associated metadata needed to interpret the result.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.