stress_test_speededness: Stress test speededness

View source: R/052-irt-validation-0-7.R

stress_test_speedednessR Documentation

Stress test speededness

Description

Stress test speededness

Usage

stress_test_speededness(
  runner,
  proportions = c(0, 0.1, 0.25, 0.4),
  replications = 50L,
  seed = 20260808L
)

Arguments

runner

Function that executes one stress-test scenario.

proportions

Speededness proportions to evaluate.

replications

Number of simulation or validation replications.

seed

Random-number seed.

Value

An object of class "eye_irt_stress_test", "data.frame", stored as a data frame, containing stress test speededness and associated metadata needed to interpret the result.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.