View source: R/075-benchmark-stress-0-9.R
| stress_test_summary | R Documentation |
Summarise stress-test metrics
stress_test_summary(x, metric = "effect")
x |
Stress-test result. |
metric |
Numeric metric column. |
A data frame containing stress-test metrics. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.