stress_tolerance_frontier: Identify the empirical stress frontier for a metric

View source: R/075-benchmark-stress-0-9.R

stress_tolerance_frontierR Documentation

Identify the empirical stress frontier for a metric

Description

Identify the empirical stress frontier for a metric

Usage

stress_tolerance_frontier(x, severity, metric, acceptable)

Arguments

x

Stress-test result.

severity

Numeric corruption/severity column.

metric

Metric column.

acceptable

Function returning TRUE/FALSE for metric values.

Value

A data frame containing the empirical stress frontier for a metric. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.