View source: R/072-sensitivity-multiverse-0-9.R
| summarise_process_sensitivity | R Documentation |
Summarise process sensitivity results
summarise_process_sensitivity(
x,
effect = "effect",
p_value = NULL,
threshold = 0,
alpha = 0.05
)
x |
Sensitivity result. |
effect |
Effect column. |
p_value |
Optional p-value column. |
threshold |
Optional substantive effect threshold. |
alpha |
Significance threshold used only when 'p_value' is supplied. |
A data frame containing process sensitivity results. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.