summarize_process_windows: Summarize extracted process windows

View source: R/060-process-window-representations-0-8.R

summarize_process_windowsR Documentation

Summarize extracted process windows

Description

Summarize extracted process windows

Usage

summarize_process_windows(x, by = NULL)

Arguments

x

'eye_process_windows' object.

by

Optional grouping columns present in the extracted table.

Value

An R object containing extracted process windows. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.