summary.eye_validation_bundle: Summarize a validation bundle object

View source: R/063-operational-validation-0-8.R

summary.eye_validation_bundleR Documentation

Summarize a validation bundle object

Description

Summarize a validation bundle object

Usage

## S3 method for class 'eye_validation_bundle'
summary(object, ...)

Arguments

object

Object supplied to the S3 method.

...

Additional arguments passed to the underlying method or helper.

Value

A named list with components "model_name", "manifest", "report", containing a validation bundle object and associated metadata or diagnostics.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.