summary.eye_validation_job_plan: summary eye validation job plan

View source: R/023-validation-orchestration.R

summary.eye_validation_job_planR Documentation

summary eye validation job plan

Description

S3 method supporting a research-scale eyeprocess object.

Usage

## S3 method for class 'eye_validation_job_plan'
summary(object, ...)

Arguments

object

Value for 'object'. See the function description and relevant article for constraints.

...

Additional arguments passed to the selected engine or method.

Value

The documented eyeprocess object, data frame, plot, report path, or adapter result.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.