View source: R/073-decision-manifests-0-9.R
| validate_decision_manifest | R Documentation |
Validate a research decision manifest
validate_decision_manifest(
x,
required_domains = c("sampling", "validity", "fixation", "pupil", "aoi", "model",
"sensitivity", "exclusions"),
require_nonempty = FALSE
)
x |
Manifest. |
required_domains |
Domains that must exist. |
require_nonempty |
If TRUE, required domains must contain at least one decision. |
A logical value or vector indicating a research decision manifest.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.