View source: R/077-negative-controls-leakage-0-9.R
| validate_feature_availability | R Documentation |
Validate feature availability against an analysis cutoff
validate_feature_availability(provenance, cutoff)
provenance |
Feature provenance table. |
cutoff |
Scalar cutoff or named vector by feature. |
A data frame containing feature availability against an analysis cutoff. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.