View source: R/051-advanced-process-irt-0-7.R
| validate_latent_space_process_similarity | R Documentation |
Validate latent-space proximity against process similarity
validate_latent_space_process_similarity(
object,
process_matrix,
entity = c("person", "item")
)
object |
A fitted eyeprocess model or audit object. |
process_matrix |
Rows correspond to persons or items in the same order as the fitted latent coordinates. |
entity |
Entity type to map or validate. |
An object of class "eye_latent_space_process_validation", stored as a named list, with components "entity", "spearman_distance_correlation", "latent_distance", "process_distance", "interpretation". It contains latent-space proximity against process similarity and associated metadata or diagnostics needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.