validate_process_windows: Validate a process-window representation

View source: R/060-process-window-representations-0-8.R

validate_process_windowsR Documentation

Validate a process-window representation

Description

Validate a process-window representation

Usage

validate_process_windows(x)

Arguments

x

Object to process, inspect, compare, or plot.

Value

A data frame containing a process-window representation. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.