View source: R/055-requested-api-completion-0-7.R
| validate_vendor_semantics | R Documentation |
Validate imported data against a vendor semantic contract
validate_vendor_semantics(data, contract, metadata = list())
data |
Imported/canonical table. |
contract |
'eye_vendor_schema_contract'. |
metadata |
Optional named metadata list. |
An object of class "eye_vendor_semantic_validation", stored as a named list, with components "pass", "vendor", "version", "fields", "aliases", "timestamp", "units", "contract". It contains imported data against a vendor semantic contract and associated metadata or diagnostics needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.