View source: R/082-validation-evidence-programs-0-9.R
| validation_acceptance_rule | R Documentation |
Define a validation acceptance rule
validation_acceptance_rule(
metric,
direction = c("max", "min", "between", "equals"),
threshold,
upper = NULL,
tolerance = 0
)
metric |
Metric name or metric column. |
direction |
Direction vector used to project multidimensional information. |
threshold |
Decision or diagnostic threshold. |
upper |
Optional upper threshold for interval-style acceptance rules. |
tolerance |
Numerical or decision tolerance. |
An object of class "eye_validation_acceptance_rule", stored as a named list, with components "metric", "direction", "threshold", "upper", "tolerance". It contains define a validation acceptance rule and associated metadata or diagnostics needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.