validation_bundle_manifest: Create a machine-readable validation manifest

View source: R/063-operational-validation-0-8.R

validation_bundle_manifestR Documentation

Create a machine-readable validation manifest

Description

Create a machine-readable validation manifest

Usage

validation_bundle_manifest(x)

Arguments

x

Object to process, inspect, compare, or plot.

Value

A data frame containing a machine-readable validation manifest. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.