validation_condition_ranking: Rank validation conditions by a transparent robustness score

View source: R/069-validation-program-0-9.R

validation_condition_rankingR Documentation

Rank validation conditions by a transparent robustness score

Description

Rank validation conditions by a transparent robustness score

Usage

validation_condition_ranking(
  x,
  weights = c(rmse = 1, abs_bias = 1, coverage_error = 1, failure_rate = 1)
)

Arguments

x

Validation result.

weights

Named weights for rmse, absolute bias, coverage error, and failure rate.

Value

A tabular R object containing rank validation conditions by a transparent robustness score; rows represent analysis units and columns contain the returned quantities.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.