View source: R/069-validation-program-0-9.R
| validation_failure_profile | R Documentation |
Failure profile for a validation programme
validation_failure_profile(x)
x |
Validation result. |
A data frame containing failure profile for a validation programme. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.