validation_failure_taxonomy: Classify common estimator failures without hiding the...

View source: R/052-irt-validation-0-7.R

validation_failure_taxonomyR Documentation

Classify common estimator failures without hiding the original message

Description

Classify common estimator failures without hiding the original message

Usage

validation_failure_taxonomy(x)

Arguments

x

Error/condition/message vector.

Value

A data frame containing classify common estimator failures without hiding the original message. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.