View source: R/023-validation-orchestration.R
| validation_job_plan | R Documentation |
Part of the research-scale validation, advanced-model, interoperability, storage, adapter, or reproducibility programme. Experimental model functions remain subject to declared evidence gates.
validation_job_plan(grid = NULL, replications = 100L, base_seed = 1L,
model_family = "unspecified", plan_id = NULL, chunk_size = 1L, metadata = list())
grid |
Scenario grid or named list of factor levels. |
replications |
Replications per design cell. |
base_seed |
Base seed used for deterministic seed allocation. |
model_family |
Model-family label. |
plan_id |
Optional explicit plan identifier. |
chunk_size |
Number of jobs assigned to each chunk. |
metadata |
Arbitrary plan metadata. |
The documented eyeprocess object, data frame, plot, report path, or adapter result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.