View source: R/052-irt-validation-0-7.R
| validation_mcse | R Documentation |
Monte Carlo standard errors for validation metrics
validation_mcse(results, metric = c("bias", "rmse", "coverage"))
results |
Validation or model results. |
metric |
Metric to calculate or audit. |
A data frame containing monte Carlo standard errors for validation metrics. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.