View source: R/082-validation-evidence-programs-0-9.R
| validation_mcse_profile | R Documentation |
Estimate Monte Carlo uncertainty for validation summaries
validation_mcse_profile(x, metric, by = character())
x |
Object to validate, summarize, verify, or otherwise process. |
metric |
Metric name or metric column. |
by |
Grouping variables or aggregation level. |
A tabular R object containing monte Carlo uncertainty for validation summaries; rows represent analysis units and columns contain the returned quantities.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.