verify_eyeprocess_validation_evidence: Verify the integrity hash of a frozen evidence bundle

View source: R/091-validation-stress-freeze-0-9.R

verify_eyeprocess_validation_evidenceR Documentation

Verify the integrity hash of a frozen evidence bundle

Description

Verify the integrity hash of a frozen evidence bundle

Usage

verify_eyeprocess_validation_evidence(x)

Arguments

x

Object to validate, summarize, verify, or otherwise process.

Value

A logical value or vector indicating verify the integrity hash of a frozen evidence bundle.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.