write_api_lifecycle_registry: Write API lifecycle registry to CSV

View source: R/071-api-lifecycle-0-9.R

write_api_lifecycle_registryR Documentation

Write API lifecycle registry to CSV

Description

Write API lifecycle registry to CSV

Usage

write_api_lifecycle_registry(registry, path)

Arguments

registry

Lifecycle registry.

path

Output path.

Value

An R object containing aPI lifecycle registry to CSV. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.