write_decision_manifest: Write a decision manifest

View source: R/073-decision-manifests-0-9.R

write_decision_manifestR Documentation

Write a decision manifest

Description

Write a decision manifest

Usage

write_decision_manifest(x, path, format = c("rds", "dput", "json"))

Arguments

x

Manifest.

path

Output path.

format

'rds', 'dput', or 'json'.

Value

An R object containing a decision manifest. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.