write_eye_targets_template: Write an explicit '_targets.R' template from a governed...

View source: R/070-governed-pipelines-0-9.R

write_eye_targets_templateR Documentation

Write an explicit '_targets.R' template from a governed pipeline

Description

Write an explicit '_targets.R' template from a governed pipeline

Usage

write_eye_targets_template(x, path = "_targets.R")

Arguments

x

Pipeline.

path

Output path.

Value

An R object containing an explicit '_targets.R' template from a governed pipeline. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.


eyeprocess documentation built on Sept. 28, 2026, 5:08 p.m.