View source: R/079-software-paper-evidence-0-9.R
| write_software_paper_evidence | R Documentation |
Write a human-readable software-paper evidence report
write_software_paper_evidence(x, path)
x |
Evidence bundle. |
path |
Markdown output path. |
An R object containing a human-readable software-paper evidence report. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.