View source: R/071-api-lifecycle-0-9.R
| api_surface_summary | R Documentation |
Summarise API surface by family and lifecycle status
api_surface_summary(inventory)
inventory |
Output of 'eye_api_inventory()' or compatible table. |
A data frame containing aPI surface by family and lifecycle status. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.