View source: R/050-process-irt-models-0-7.R
| audit_distractor_attention | R Documentation |
Audit distractor attention patterns
audit_distractor_attention(
data,
response_option = "response_option",
option_gaze,
chosen_suffix = NULL
)
data |
Input data frame or compatible tabular object. |
response_option |
Column identifying the selected response option. |
option_gaze |
Option-level gaze variables. |
chosen_suffix |
Suffix identifying the selected option indicator. |
A data frame containing distractor attention patterns. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.