View source: R/065-frontier-gates-0-8.R
| audit_frontier_model_contract | R Documentation |
Audit whether a gated frontier model has a minimum evidence contract
audit_frontier_model_contract(x, evidence = list())
x |
Gated model object. |
evidence |
Named evidence objects. |
A data frame containing whether a gated frontier model has a minimum evidence contract. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.