Audit whether a gated frontier model has a minimum evidence contract
Source:R/065-frontier-gates-0-8.R
audit_frontier_model_contract.RdAudit whether a gated frontier model has a minimum evidence contract
Usage
audit_frontier_model_contract(x, evidence = list())