View source: R/055-requested-api-completion-0-7.R
| audit_latent_distribution | R Documentation |
Audit the empirical latent-trait distribution
audit_latent_distribution(theta, tail_z = 3)
theta |
Numeric latent-trait draws/estimates. |
tail_z |
Absolute standardized threshold used for tail-rate diagnostics. |
A data frame containing the empirical latent-trait distribution. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.