View source: R/052-irt-validation-0-7.R
| audit_rmse | R Documentation |
Audit rmse
audit_rmse(results, threshold = 0.3, by = c("scenario", "engine", "parameter"))
results |
Validation or model results. |
threshold |
Decision or diagnostic threshold. |
by |
Grouping variables used when summarizing results. |
An R object containing rmse. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.