View source: R/052-irt-validation-0-7.R
| audit_sbc | R Documentation |
Uses binned chi-square diagnostics as a coarse screening diagnostic and also reports the mean/variance of normalized ranks. It is not a replacement for rank-histogram inspection.
audit_sbc(x, bins = 10L, alpha = 0.01)
x |
Object to print, plot, summarize, or audit. |
bins |
Number of bins used by the diagnostic. |
alpha |
Significance or tail-probability level. |
An object of class "eye_sbc_audit", "data.frame", stored as a data frame, containing sBC rank uniformity and associated metadata needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.