View source: R/068-bayesian-3pl-process-diagnostics-0-8.R
| bayesian_process_diagnostic_flags | R Documentation |
Extract compact Bayesian process-model diagnostic flags
bayesian_process_diagnostic_flags(
x,
rhat_threshold = 1.01,
ess_threshold = 400
)
x |
An 'eye_bayesian_process_dashboard'. |
rhat_threshold |
Review threshold for R-hat. |
ess_threshold |
Review threshold for bulk/tail effective sample size. |
An R object containing compact Bayesian process-model diagnostic flags. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.