View source: R/075-benchmark-stress-0-9.R
| benchmark_memory_estimate | R Documentation |
Memory estimate for an R object or generated problem size
benchmark_memory_estimate(x, generator = NULL)
x |
Object, or numeric n when 'generator' is supplied. |
generator |
Optional function taking n. |
A data frame containing memory estimate for an R object or generated problem size. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.