View source: R/075-benchmark-stress-0-9.R
| benchmark_scaling_curve | R Documentation |
Estimate scaling exponent from benchmark results
benchmark_scaling_curve(x)
x |
Benchmark result. |
A data frame containing scaling exponent from benchmark results. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.