View source: R/050-process-irt-models-0-7.R
| classify_item_missingness | R Documentation |
Classify item missingness using exposure and response evidence
classify_item_missingness(
data,
response = "response",
reached = "reached",
inspected = NULL,
started = NULL
)
data |
Input data frame or compatible tabular object. |
response |
Response variable or response-column name. |
reached |
Indicator that the item was reached. |
inspected |
Indicator that the item or response area was inspected. |
started |
Indicator that responding was initiated. |
An object of class "factor", stored as an R object, containing classify item missingness using exposure and response evidence and associated metadata needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.