View source: R/067-advanced-sensitivity-diagnostics-0-8.R
| compare_bayesian_process_models | R Documentation |
Compare Bayesian process models by LOO or Bayes factor
compare_bayesian_process_models(..., method = c("loo", "bayes_factor"))
... |
Fitted brms models. |
method |
'loo' or 'bayes_factor'. |
An R object containing bayesian process models by LOO or Bayes factor. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.