View source: R/073-decision-manifests-0-9.R
| compare_decision_manifests | R Documentation |
Compare two research decision manifests
compare_decision_manifests(old, new)
old |
Earlier manifest. |
new |
Later manifest. |
An object of class "eye_decision_manifest_diff", "data.frame", stored as a data frame, containing two research decision manifests and associated metadata needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.