View source: R/059-deployment-drift-0-8.R
| compare_deployment_batches | R Documentation |
Compare two deployment batches descriptively
compare_deployment_batches(
data,
batch = "deployment_batch",
batch_a,
batch_b,
metrics = NULL,
item = "item_id"
)
data |
Deployment data. |
batch |
Batch column. |
batch_a, batch_b |
Values to compare. |
metrics |
Metrics to compare. |
item |
Optional item identifier for item-matched differences. |
A data frame containing two deployment batches descriptively. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.