View source: R/062-context-process-structure-0-8.R
| compare_process_criterion_models | R Documentation |
Compare process external-validity models
compare_process_criterion_models(x)
x |
Object to process, inspect, compare, or plot. |
A data frame containing process external-validity models. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.