View source: R/061-pupil-advanced-representations-0-8.R
| compare_raw_adjusted_pupil | R Documentation |
Compare raw and confound-adjusted pupil values
compare_raw_adjusted_pupil(x)
x |
Object to process, inspect, compare, or plot. |
A data frame containing raw and confound-adjusted pupil values. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.