View source: R/062-context-process-structure-0-8.R
| compare_visual_context_irt | R Documentation |
Compare base and visual-context IRT models
compare_visual_context_irt(x)
x |
Object to process, inspect, compare, or plot. |
A data frame containing base and visual-context IRT models. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.