View source: R/081-validation-extras-0-9.R
| coverage_calibration_curve | R Documentation |
Interval coverage calibration curve
coverage_calibration_curve(truth, lower, upper, nominal = NULL)
truth |
True values. |
lower |
Matrix/data.frame of lower limits or numeric vector. |
upper |
Matrix/data.frame of upper limits or numeric vector. |
nominal |
Nominal coverage labels, one per interval column. |
A data frame containing interval coverage calibration curve. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.