View source: R/073-decision-manifests-0-9.R
| decision_manifest_diff | R Documentation |
Alias for manifest comparison emphasizing changed decision paths
decision_manifest_diff(old, new)
old |
Earlier manifest. |
new |
Later manifest. |
An R object containing alias for manifest comparison emphasizing changed decision paths. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.