View source: R/073-decision-manifests-0-9.R
| decision_manifest_hash | R Documentation |
Stable hash of decision content
decision_manifest_hash(x)
x |
Manifest or decision object. |
An R object containing stable hash of decision content. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.