View source: R/059-deployment-drift-0-8.R
| drift_by_device | R Documentation |
Drift audit stratified by device
drift_by_device(data, device = "device_id", ...)
data |
Data frame containing the required process variables. |
device |
Name of the column identifying device. |
... |
Additional arguments passed to the underlying method or helper. |
An R object containing drift audit stratified by device. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.