View source: R/059-deployment-drift-0-8.R
| drift_by_site | R Documentation |
Drift audit stratified by study site
drift_by_site(data, site = "site_id", ...)
data |
Data frame containing the required process variables. |
site |
Name of the column identifying site. |
... |
Additional arguments passed to the underlying method or helper. |
An R object containing drift audit stratified by study site. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.