View source: R/059-deployment-drift-0-8.R
| drift_by_stimulus_version | R Documentation |
Drift audit stratified by stimulus version
drift_by_stimulus_version(data, stimulus_version = "stimulus_version", ...)
data |
Data frame containing the required process variables. |
stimulus_version |
Name of the column identifying stimulus version. |
... |
Additional arguments passed to the underlying method or helper. |
An R object containing drift audit stratified by stimulus version. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.