View source: R/051-advanced-process-irt-0-7.R
| equate_irt_scales | R Documentation |
Implements mean-sigma, mean-mean, Stocking-Lord, and Haebara linking for dichotomous 2PL-style item parameters. New-form parameters are transformed onto the reference scale using theta_ref = A * theta_new + B.
equate_irt_scales(
reference,
new,
method = c("stocking-lord", "haebara", "mean-sigma", "mean-mean"),
theta_grid = seq(-4, 4, length.out = 81)
)
reference |
Reference-scale parameters or data. |
new |
New-scale parameters or data. |
method |
Method used for estimation, linking, or comparison. |
theta_grid |
Grid of latent-trait values used for evaluation. |
An object of class "eye_irt_equating", stored as a named list, with components "A", "B", "method", "transformed", "reference", "new", "equation". It contains equate IRT scales using anchor item parameters and associated metadata or diagnostics needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.