View source: R/055-requested-api-completion-0-7.R
| event_roundtrip_audit | R Documentation |
Audit event survival across an interchange round trip
event_roundtrip_audit(source_events, roundtrip_events, hed_column = NULL, ...)
source_events, roundtrip_events |
Event tables. |
hed_column |
Optional HED annotation column to compare structurally. |
... |
Arguments forwarded to 'event_semantics_audit()'. |
An object of class "eye_event_roundtrip_audit", stored as a named list, with components "status", "event_semantics", "hed". It contains event survival across an interchange round trip and associated metadata or diagnostics needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.