View source: R/082-validation-evidence-programs-0-9.R
| expand_eyeprocess_validation_plan | R Documentation |
Expand a validation-evidence plan to a scenario table
expand_eyeprocess_validation_plan(x)
x |
Object to validate, summarize, verify, or otherwise process. |
An R object containing expand a validation-evidence plan to a scenario table. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.