View source: R/070-governed-pipelines-0-9.R
| export_eye_pipeline | R Documentation |
Export a pipeline manifest and optional run status
export_eye_pipeline(x, path)
x |
Pipeline or run. |
path |
CSV path. |
An R object containing a pipeline manifest and optional run status. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.