View source: R/075-benchmark-stress-0-9.R
| eye_benchmark_design | R Documentation |
Define a computational benchmark design
eye_benchmark_design(
n_obs = c(10000, 1e+05, 1e+06),
repetitions = 3L,
label = "eyeprocess_scaling"
)
n_obs |
Observation counts. |
repetitions |
Repetitions per size. |
label |
Benchmark label. |
A tabular R object containing define a computational benchmark design; rows represent analysis units and columns contain the returned quantities.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.