View source: R/070-governed-pipelines-0-9.R
| eye_targets_manifest | R Documentation |
This function does not execute or silently translate arbitrary closures into a targets pipeline. It provides the dependency contract required to build an explicit '_targets.R' file.
eye_targets_manifest(x)
x |
Pipeline. |
A data frame containing a targets-compatible dependency manifest. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.