Skip to contents

This function does not execute or silently translate arbitrary closures into a targets pipeline. It provides the dependency contract required to build an explicit `_targets.R` file.

Usage

eye_targets_manifest(x)

Arguments

x

Pipeline.