Create a targets-compatible dependency manifest
Source:R/070-governed-pipelines-0-9.R
eye_targets_manifest.RdThis function does not execute or silently translate arbitrary closures into a targets pipeline. It provides the dependency contract required to build an explicit `_targets.R` file.