View source: R/086-irt-linking-invariance-0-9.R
| eyeprocess_irt_anchor_purification | R Documentation |
Iteratively remove anchors exceeding a supplied effect threshold
eyeprocess_irt_anchor_purification(
items,
effect_fun,
initial = items$item_id,
threshold = 0.1,
max_iter = 10L
)
items |
Item-parameter data frame or item collection. |
effect_fun |
Function that computes the anchor-screening effect. |
initial |
Initial value, state, or anchor set. |
threshold |
Decision or diagnostic threshold. |
max_iter |
Maximum number of iterations. |
An object of class "eye_irt_anchor_purification", stored as a named list, with components "anchors", "history", "threshold". It contains iteratively remove anchors exceeding a supplied effect threshold and associated metadata or diagnostics needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.