View source: R/086-irt-linking-invariance-0-9.R
| eyeprocess_irt_apply_link | R Documentation |
Apply linear IRT scale-linking coefficients
eyeprocess_irt_apply_link(items, link)
items |
Item-parameter data frame or item collection. |
link |
IRT scale-linking coefficients or linking object. |
An R object containing linear IRT scale-linking coefficients. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.