View source: R/093-irt-advanced-diagnostics-governance-0-9.R
| eyeprocess_irt_classification_precision | R Documentation |
Summarise decision precision at one or more theta cut scores
eyeprocess_irt_classification_precision(
theta_estimate,
standard_error,
cut_score = 0,
confidence = 0.95
)
theta_estimate |
Estimated latent-trait values. |
standard_error |
Standard errors corresponding to the estimates. |
cut_score |
Latent-scale classification cut score. |
confidence |
Requested confidence level. |
A tabular R object containing decision precision at one or more theta cut scores; rows represent analysis units and columns contain the returned quantities.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.