Differential item functioning effect curve from two parameter sets
Source:R/086-irt-linking-invariance-0-9.R
eyeprocess_irt_dif_effect_curve.RdDifferential item functioning effect curve from two parameter sets
Usage
eyeprocess_irt_dif_effect_curve(
reference_item,
focal_item,
theta = seq(-4, 4, length.out = 81)
)