View source: R/086-irt-linking-invariance-0-9.R
| eyeprocess_irt_dtf_curve | R Documentation |
Differential test functioning effect curve
eyeprocess_irt_dtf_curve(reference, focal, theta = seq(-4, 4, length.out = 81))
reference |
Reference-form or reference-group item parameters. |
focal |
Focal-form or focal-group item parameters. |
theta |
Latent-trait value or vector of latent-trait values. |
An object of class "eye_irt_dtf_curve", "data.frame", stored as a data frame, containing differential test functioning effect curve and associated metadata needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.