View source: R/094-validation-paper-tables-atlas-0-9.R
| eyeprocess_irt_engine_evidence_table | R Documentation |
Build an external-engine capability and availability table
eyeprocess_irt_engine_evidence_table()
A data frame containing an external-engine capability and availability table. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.