View source: R/083-irt-foundations-information-0-9.R
| eyeprocess_irt_expected_score | R Documentation |
Expected item score
eyeprocess_irt_expected_score(
theta,
family = c("2pl", "3pl", "4pl", "grm", "gpcm", "nominal"),
...
)
theta |
Latent-trait value or vector of latent-trait values. |
family |
IRT response family or model family. |
... |
Additional arguments passed to the selected method or external engine. |
A numeric value or vector containing expected item score.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.