View source: R/084-irt-diagnostics-0-9.R
| eyeprocess_irt_extreme_score_audit | R Documentation |
Audit extreme response scores without assigning behavioral labels
eyeprocess_irt_extreme_score_audit(
responses,
lower_fraction = 0.02,
upper_fraction = 0.98
)
responses |
Response matrix or response data. |
lower_fraction |
Lower extreme-score fraction. |
upper_fraction |
Upper extreme-score fraction. |
A data frame containing extreme response scores without assigning behavioral labels. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.