View source: R/085-irt-scoring-adaptive-0-9.R
| eyeprocess_irt_information_targeting | R Documentation |
Audit how well item information targets a theta distribution
eyeprocess_irt_information_targeting(items, theta, weights = NULL, D = 1)
items |
Item-parameter data frame or item collection. |
theta |
Latent-trait value or vector of latent-trait values. |
weights |
Optional numerical weights. |
D |
Logistic scaling constant. |
An object of class "eye_irt_information_targeting", stored as a named list, with components "weighted_information", "weighted_sem", "curve", "weights". It contains how well item information targets a theta distribution and associated metadata or diagnostics needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.