Audit how well item information targets a theta distribution
Source:R/085-irt-scoring-adaptive-0-9.R
eyeprocess_irt_information_targeting.RdAudit how well item information targets a theta distribution

R/085-irt-scoring-adaptive-0-9.R
eyeprocess_irt_information_targeting.RdAudit how well item information targets a theta distribution