Select the most informative eligible item at a theta estimate
Source:R/085-irt-scoring-adaptive-0-9.R
eyeprocess_irt_item_selection.RdSelect the most informative eligible item at a theta estimate
Usage
eyeprocess_irt_item_selection(
bank,
theta,
administered = character(),
exposure = NULL,
content_required = NULL,
D = 1
)Arguments
- bank
Validated item-bank object.
- theta
Latent-trait value or vector of latent-trait values.
- administered
Identifiers or records for administered items.
- exposure
Item exposure information used by the adaptive-selection rule.
- content_required
Content constraints required for item selection.
- D
Logistic scaling constant.