View source: R/086-irt-linking-invariance-0-9.R
| eyeprocess_irt_link_stability | R Documentation |
Compare linking estimates across anchor subsets
eyeprocess_irt_link_stability(
reference,
focal,
anchor_sets,
method = c("mean-sigma", "mean-mean", "Stocking-Lord", "Haebara")
)
reference |
Reference-form or reference-group item parameters. |
focal |
Focal-form or focal-group item parameters. |
anchor_sets |
Value supplied for the anchor sets argument. |
method |
Scoring, linking, or analysis method. |
An object of class "eye_irt_link_stability", stored as a named list, with components "table", "sd_A", "sd_B", "method". It contains linking estimates across anchor subsets and associated metadata or diagnostics needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.