View source: R/084-irt-diagnostics-0-9.R
| eyeprocess_irt_local_dependence_pairs | R Documentation |
Extract high residual-dependence item pairs
eyeprocess_irt_local_dependence_pairs(q3, threshold = 0.2, absolute = TRUE)
q3 |
Q3 residual-correlation matrix or summary. |
threshold |
Decision or diagnostic threshold. |
absolute |
Whether diagnostic thresholds apply to absolute values. |
A data frame containing high residual-dependence item pairs. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.