View source: R/093-irt-advanced-diagnostics-governance-0-9.R
| eyeprocess_irt_model_card_audit | R Documentation |
Audit completeness of an IRT model card
eyeprocess_irt_model_card_audit(card)
card |
Value supplied for the card argument. |
A data frame containing completeness of an IRT model card. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.