View source: R/084-irt-diagnostics-0-9.R
| eyeprocess_irt_monotonicity_audit | R Documentation |
Audit monotonicity of an item response curve
eyeprocess_irt_monotonicity_audit(theta, probability, tolerance = 1e-08)
theta |
Latent-trait value or vector of latent-trait values. |
probability |
Model-implied probability vector. |
tolerance |
Numerical or decision tolerance. |
An object of class "eye_irt_monotonicity_audit", stored as a named list, with components "monotone_non_decreasing", "n_decreases", "largest_decrease", "theta", "probability". It contains monotonicity of an item response curve and associated metadata or diagnostics needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.