View source: R/093-irt-advanced-diagnostics-governance-0-9.R
| eyeprocess_irt_person_fit_lz | R Documentation |
Computes a Bernoulli response-pattern log-likelihood standardized against its model-implied mean and variance. Extreme values are model diagnostics, not evidence of cheating, disengagement, or a psychological state.
eyeprocess_irt_person_fit_lz(observed, expected, min_probability = 1e-08)
observed |
Observed responses or observed values. |
expected |
Model-expected probabilities or expected values. |
min_probability |
Lower probability bound used for numerical stabilization. |
A data frame containing standardized log-likelihood person-fit diagnostic. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.