View source: R/084-irt-diagnostics-0-9.R
| eyeprocess_irt_person_fit_residuals | R Documentation |
Compute person residual fit summaries
eyeprocess_irt_person_fit_residuals(
responses,
probabilities,
person_ids = rownames(responses)
)
responses |
Response matrix or response data. |
probabilities |
Probability matrix or vector, with dimensions appropriate to the model. |
person_ids |
Optional person identifiers. |
An object of class "eye_irt_person_fit", "data.frame", stored as a data frame, containing person residual fit summaries and associated metadata needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.