View source: R/085-irt-scoring-adaptive-0-9.R
| eyeprocess_irt_plausible_values | R Documentation |
Draw plausible values from a discrete posterior grid
eyeprocess_irt_plausible_values(score, n = 5L, seed = 1L)
score |
Score object containing posterior or uncertainty information. |
n |
Number of values, draws, or plausible values to generate. |
seed |
Random-number seed for reproducible execution. |
An R object containing plausible values from a discrete posterior grid. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.