Compute Yen-style Q3 residual correlations
Usage
eyeprocess_irt_q3(responses, probabilities, use = "pairwise.complete.obs")
Arguments
- responses
Response matrix or response data.
- probabilities
Probability matrix or vector, with dimensions appropriate to the model.
- use
Missing-data handling mode passed to the residual correlation calculation.