View source: R/085-irt-scoring-adaptive-0-9.R
| eyeprocess_irt_score_table | R Documentation |
Score a response matrix with EAP, MAP, or ML
eyeprocess_irt_score_table(
responses,
items,
method = c("EAP", "MAP", "ML"),
person_ids = rownames(responses),
...
)
responses |
Response matrix or response data. |
items |
Item-parameter data frame or item collection. |
method |
Scoring, linking, or analysis method. |
person_ids |
Optional person identifiers. |
... |
Additional arguments passed to the selected method or external engine. |
A tabular R object containing a response matrix with EAP, MAP, or ML; rows represent analysis units and columns contain the returned quantities.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.