View source: R/083-irt-foundations-information-0-9.R
| eyeprocess_irt_test_information | R Documentation |
Compute a test information curve from item parameters
eyeprocess_irt_test_information(theta, items, D = 1)
theta |
Latent-trait value or vector of latent-trait values. |
items |
Item-parameter data frame or item collection. |
D |
Logistic scaling constant. |
An object of class "eye_irt_information_profile", "data.frame", stored as a data frame, containing a test information curve from item parameters and associated metadata needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.