View source: R/090-irt-multidimensional-cdm-0-9.R
| eyeprocess_irt_testlet_spec | R Documentation |
Declare a testlet structure for bifactor/two-tier IRT engines
eyeprocess_irt_testlet_spec(item_id, testlet, general_dimension = "general")
item_id |
Item identifier or vector of item identifiers. |
testlet |
Testlet membership identifier. |
general_dimension |
General dimension name or index. |
An object of class "eye_irt_testlet_spec", "data.frame", stored as a data frame, containing declare a testlet structure for bifactor/two-tier IRT engines and associated metadata needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.