View source: R/087-irt-process-joint-0-9.R
| eyeprocess_multichannel_measurement_map | R Documentation |
Construct a multichannel measurement map
eyeprocess_multichannel_measurement_map(
response = "accuracy",
channels = c("response_time", "dwell", "pupil", "transitions"),
role = NULL
)
response |
Observed item response or response variable. |
channels |
Names or definitions of measurement channels. |
role |
Declared role of each measurement channel. |
A data frame containing a multichannel measurement map. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.