View source: R/087-irt-process-joint-0-9.R
| eyeprocess_process_person_profile | R Documentation |
Aggregate process channels by person
eyeprocess_process_person_profile(data, person, channels)
data |
Input data frame, matrix, or compatible analysis object. |
person |
Name of the person identifier column. |
channels |
Names or definitions of measurement channels. |
A tabular R object containing aggregate process channels by person; rows represent analysis units and columns contain the returned quantities.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.