View source: R/091-validation-stress-freeze-0-9.R
| eyeprocess_validation_claim_matrix | R Documentation |
Build a machine-readable validation claim/evidence matrix
eyeprocess_validation_claim_matrix(
claim_id,
claim,
evidence_id,
evidence_type,
status = "qualified",
boundary = NA_character_
)
claim_id |
Unique identifier for the claim. |
claim |
Text of the software-validation claim. |
evidence_id |
Identifier of evidence supporting or testing the claim. |
evidence_type |
Type or class of evidence. |
status |
Evidence, model, or governance status. |
boundary |
Explicit interpretation or scope boundary for the claim. |
A data frame containing a machine-readable validation claim/evidence matrix. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.