View source: R/094-validation-paper-tables-atlas-0-9.R
| eyeprocess_validation_evidence_index | R Documentation |
Create an index over frozen validation evidence artifacts
eyeprocess_validation_evidence_index(root, recursive = TRUE)
root |
Root directory for evidence indexing. |
recursive |
Whether evidence files are indexed recursively. |
A data frame containing an index over frozen validation evidence artifacts. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.