View source: R/078-reproducibility-provenance-0-9.R
| file_hash_manifest | R Documentation |
Build a file hash manifest
file_hash_manifest(paths, algorithm = c("md5", "sha256"))
paths |
File paths. |
algorithm |
Hash algorithm; currently 'md5' uses base R, 'sha256' uses openssl when available. |
A data frame containing a file hash manifest. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.