fit brms adapter
fit_brms_adapter.RdPart of the research-scale validation, advanced-model, interoperability, storage, adapter, or reproducibility programme. Experimental model functions remain subject to declared evidence gates.
Arguments
- formula
Value for `formula`. See the function description and relevant article for constraints.
- data
Value for `data`. See the function description and relevant article for constraints.
- purpose
Value for `purpose`. See the function description and relevant article for constraints.
- ...
Additional arguments passed to the selected engine or method.