View source: R/051-advanced-process-irt-0-7.R
| fit_continuous_time_irt | R Documentation |
Continuous-time IRT external-engine gate
fit_continuous_time_irt(data, external_engine = NULL, ...)
data |
Input data frame or compatible tabular object. |
external_engine |
Validated external fitting function. |
... |
Additional arguments passed to the selected model, engine, or method. |
An object of class "eye_continuous_time_irt", stored as a named list, with components "model", "status". It contains continuous-time IRT external-engine gate and associated metadata or diagnostics needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.