View source: R/088-irt-engine-adapters-0-9.R
| fit_eyeprocess_gdina | R Documentation |
Fit a G-DINA cognitive-diagnosis model without fallback substitution
fit_eyeprocess_gdina(dat, Q, model = "GDINA", ..., engine = "GDINA")
dat |
Response data supplied to the GDINA engine. |
Q |
Binary item-by-attribute Q-matrix. |
model |
Model specification passed to the selected external engine. |
... |
Additional arguments passed to the selected method or external engine. |
engine |
Requested estimation or analysis engine. |
An object of class "eye_external_irt_fit", stored as a named list, with components "status", "engine", "fit", "call". It contains a G-DINA cognitive-diagnosis model without fallback substitution and associated metadata or diagnostics needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.