View source: R/088-irt-engine-adapters-0-9.R
| fit_eyeprocess_lnirt | R Documentation |
Fit a joint response/response-time LNIRT model without fallback substitution
fit_eyeprocess_lnirt(Y, RT, quadratic = FALSE, ..., engine = "LNIRT")
Y |
Item-response matrix supplied to LNIRT. |
RT |
Response-time matrix supplied to LNIRT. |
quadratic |
Whether the LNIRT quadratic option is requested. |
... |
Additional arguments passed to the selected method or external engine. |
engine |
Requested estimation or analysis engine. |
An object of class "eye_external_irt_fit", stored as a named list, with components "status", "engine", "fit", "call", "rt_scale". It contains a joint response/response-time LNIRT model without fallback substitution and associated metadata or diagnostics needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.