View source: R/088-irt-engine-adapters-0-9.R
| fit_eyeprocess_tam | R Documentation |
Fit a TAM model without substituting another estimator
fit_eyeprocess_tam(
resp,
model = c("rasch", "2pl", "gpcm"),
...,
engine = "TAM"
)
resp |
Response matrix supplied to TAM. |
model |
Model specification passed to the selected external engine. |
... |
Additional arguments passed to the selected method or external engine. |
engine |
Requested estimation or analysis engine. |
An object of class "eye_external_irt_fit", stored as a named list, with components "status", "engine", "fit", "call". It contains a TAM model without substituting another estimator and associated metadata or diagnostics needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.