Part of the research-scale validation, advanced-model, interoperability, storage, adapter, or reproducibility programme. Experimental model functions remain subject to declared evidence gates.
Usage
fit_gaze_diffusion_stan(prepared, seed = 1L, refresh = 0L, output_dir = NULL, ...)
Arguments
- prepared
Prepared data.
- seed
Seed.
- refresh
CmdStan refresh interval.
- output_dir
Optional output directory.
- ...
Additional sampling arguments.
Value
The documented eyeprocess object, data frame, plot, report path, or adapter result.