View source: R/027-strategy-diffusion-engines.R View source: R/022-advanced-models-v2.R
| fit_theory_strategy_irt | R Documentation |
Part of the research-scale validation, advanced-model, interoperability, storage, adapter, or reproducibility programme. Experimental model functions remain subject to declared evidence gates.
fit_theory_strategy_irt(data, spec, seed = 1L, response = NULL, participant = NULL,
item = NULL, ...)
data |
Trial-level data. |
spec |
Strategy specification. |
seed |
Seed. |
response |
Value for 'response'. See the function description and relevant article for constraints. |
participant |
Value for 'participant'. See the function description and relevant article for constraints. |
item |
Value for 'item'. See the function description and relevant article for constraints. |
... |
Engine arguments. |
The documented eyeprocess object, data frame, plot, report path, or adapter result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.