Fit a theory-constrained strategy mixture
fit_theory_strategy_irt.RdPart of the research-scale validation, advanced-model, interoperability, storage, adapter, or reproducibility programme. Experimental model functions remain subject to declared evidence gates.
Usage
fit_theory_strategy_irt(data, spec, seed = 1L, response = NULL, participant = NULL,
item = NULL, ...)Arguments
- data
Trial-level data.
- spec
Strategy specification.
- seed
Seed.
- response
Value for `response`. See the function description and relevant article for constraints.
- participant
Value for `participant`. See the function description and relevant article for constraints.
- item
Value for `item`. See the function description and relevant article for constraints.
- ...
Engine arguments.