View source: R/094-validation-paper-tables-atlas-0-9.R
| freeze_eyeprocess_validation_atlas | R Documentation |
Freeze a validation atlas with a reproducibility fingerprint
freeze_eyeprocess_validation_atlas(atlas, metadata = list())
atlas |
Validation-evidence atlas object. |
metadata |
Named metadata to store with the frozen object. |
An object of class "eye_validation_atlas_freeze", stored as a named list, with components "payload", "hash", "frozen". It contains freeze a validation atlas with a reproducibility fingerprint and associated metadata or diagnostics needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.