View source: R/079-software-paper-evidence-0-9.R
| freeze_software_paper_evidence | R Documentation |
Freeze software-paper evidence to an RDS with a hash
freeze_software_paper_evidence(x, path)
x |
Evidence bundle. |
path |
Output path. |
A data frame containing freeze software-paper evidence to an RDS with a hash. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.