View source: R/069-validation-program-0-9.R
| freeze_validation_reference | R Documentation |
Freeze a compact validation reference for regression testing
freeze_validation_reference(x, path = NULL, digits = 8L)
x |
Validation result. |
path |
Optional RDS path. |
digits |
Numeric rounding applied before hashing. |
An object of class "eye_validation_reference", stored as a named list, with components "summary", "failure_profile", "design_hash", "summary_hash", "created_at", "status". It contains freeze a compact validation reference for regression testing and associated metadata or diagnostics needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.