View source: R/068-bayesian-3pl-process-diagnostics-0-8.R
| gaze_anchored_3pl_alignment | R Documentation |
Return the process-alignment table from a gaze-anchored 3PL audit
gaze_anchored_3pl_alignment(x)
x |
An 'eye_gaze_anchored_3pl_audit'. |
An R object containing return the process-alignment table from a gaze-anchored 3PL audit. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.