View source: R/049-multimodal-irt-registry.R
| get_irt_model | R Documentation |
Retrieve a registered multimodal IRT model
get_irt_model(id)
id |
Stable identifier. |
An R object containing retrieve a registered multimodal IRT model. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.