View source: R/075-benchmark-stress-0-9.R
| inject_aoi_label_noise | R Documentation |
Inject AOI label noise
inject_aoi_label_noise(data, aoi = "aoi", proportion, seed = 1L)
data |
Data. |
aoi |
AOI label column. |
proportion |
Proportion reassigned to another observed label. |
seed |
Seed. |
An R object containing inject AOI label noise. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.