View source: R/075-benchmark-stress-0-9.R
| inject_calibration_offset | R Documentation |
Inject additive gaze calibration offset in coordinate units
inject_calibration_offset(
data,
x = "gaze_x",
y = "gaze_y",
offset_x = 0,
offset_y = 0
)
data |
Data. |
x, y |
Gaze coordinate columns. |
offset_x, offset_y |
Additive offsets in the same units as x/y. |
An R object containing inject additive gaze calibration offset in coordinate units. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.