View source: R/075-benchmark-stress-0-9.R
| inject_device_shift | R Documentation |
Inject an additive device/site shift in a numeric feature
inject_device_shift(data, column, shift, rows = NULL)
data |
Data. |
column |
Numeric column. |
shift |
Additive shift. |
rows |
Optional logical/index rows affected. |
An R object containing inject an additive device/site shift in a numeric feature. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.