View source: R/075-benchmark-stress-0-9.R
| inject_sampling_jitter | R Documentation |
Inject timestamp jitter
inject_sampling_jitter(data, time = "timestamp_ms", sd, seed = 1L)
data |
Data. |
time |
Timestamp column. |
sd |
Jitter standard deviation in timestamp units. |
seed |
Seed. |
An R object containing inject timestamp jitter. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.