View source: R/055-requested-api-completion-0-7.R
| latent_distribution_stress_test | R Documentation |
Public roadmap alias for 'stress_test_latent_distribution()'.
latent_distribution_stress_test(...)
... |
Additional arguments passed to the selected model, engine, or method. |
An R object containing stress-test IRT estimators across latent distributions. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.