View source: R/073-decision-manifests-0-9.R
| lock_decision_manifest | R Documentation |
Lock a decision manifest by content hash
lock_decision_manifest(x, label = "analysis_decisions")
x |
Manifest. |
label |
Optional lock label. |
An object of class "eye_decision_manifest_lock", stored as a named list, with components "manifest", "manifest_hash", "label", "locked_at", "status". It contains lock a decision manifest by content hash and associated metadata or diagnostics needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.