View source: R/028-api-storage-adapters.R
| migrate_eye_storage_schema | R Documentation |
Part of the research-scale validation, advanced-model, interoperability, storage, adapter, or reproducibility programme. Experimental model functions remain subject to declared evidence gates.
migrate_eye_storage_schema(storage, target_path, target_version = "2.0.0",
format = NULL, overwrite = FALSE)
storage |
Storage object or path. |
target_path |
Destination. |
target_version |
Target schema version. |
format |
Target format. |
overwrite |
Whether to replace target. |
The documented eyeprocess object, data frame, plot, report path, or adapter result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.