View source: R/102-multimodal-m2-evidence-0-10.R
| multimodal_m2_process_information | R Documentation |
Computes two complementary quantities on a common response target: response-target PSIS-LOO ELPD and posterior variance of person ability. This avoids simply summing channel Fisher information under a joint correlated model.
multimodal_m2_process_information(x)
x |
An 'eye_multimodal_m2_ablation'. |
An 'eye_multimodal_m2_information'.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.