View source: R/077-negative-controls-leakage-0-9.R
| outcome_blind_feature_audit | R Documentation |
Audit whether candidate predictors can be constructed without an outcome column
outcome_blind_feature_audit(data, outcome, feature_fun)
data |
Data frame. |
outcome |
Outcome column name. |
feature_fun |
Function receiving outcome-hidden data and returning features. |
A named list with components "status", "outcome", "feature_result", "error", "warnings", "input_columns", "interpretation", containing whether candidate predictors can be constructed without an outcome column and associated metadata or diagnostics.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.