View source: R/070-governed-pipelines-0-9.R
| pipeline_failures | R Documentation |
Return failed pipeline steps
pipeline_failures(x)
x |
Pipeline run. |
A data frame containing return failed pipeline steps. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.