View source: R/070-governed-pipelines-0-9.R
| pipeline_result | R Documentation |
Extract a pipeline result by step name
pipeline_result(x, step)
x |
Pipeline run. |
step |
Step name. |
An R object containing a pipeline result by step name. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.