View source: R/070-governed-pipelines-0-9.R
| pipeline_step_status | R Documentation |
Pipeline step status table
pipeline_step_status(x)
x |
Pipeline run. |
A data frame containing pipeline step status table. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.