View source: R/064-next-generation-plots-0-8.R
| plot.eye_aoi_growth_curve | R Documentation |
Plot aoi growth curve diagnostics
## S3 method for class 'eye_aoi_growth_curve'
plot(x, ...)
x |
Object to process, inspect, compare, or plot. |
... |
Additional arguments passed to the underlying method or helper. |
Invisibly returns the plotting result when available; the primary effect is drawing plot aoi growth curve diagnostics.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.