View source: R/064-next-generation-plots-0-8.R
| plot.eye_candidate_item_bank_audit | R Documentation |
Plot candidate item bank audit diagnostics
## S3 method for class 'eye_candidate_item_bank_audit'
plot(x, ...)
x |
Object to process, inspect, compare, or plot. |
... |
Additional arguments passed to the underlying method or helper. |
Invisibly returns the plotting result when available; the primary effect is drawing plot candidate item bank audit diagnostics.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.