View source: R/066-process-decision-features-0-8.R
| plot.eye_decision_process_proxy | R Documentation |
Plot decision process proxy diagnostics
## S3 method for class 'eye_decision_process_proxy'
plot(x, ...)
x |
Object to process, inspect, compare, or plot. |
... |
Additional arguments passed to the underlying method or helper. |
Invisibly returns the plotting result when available; the primary effect is drawing plot decision process proxy diagnostics.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.