View source: R/065-frontier-gates-0-8.R
| plot.eye_gated_process_model | R Documentation |
Plot gated process model diagnostics
## S3 method for class 'eye_gated_process_model'
plot(x, ...)
x |
Object to process, inspect, compare, or plot. |
... |
Additional arguments passed to the underlying method or helper. |
Invisibly returns the plotting result when available; the primary effect is drawing plot gated process model diagnostics.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.