View source: R/053-process-irt-plots-0-7.R
| plot.eye_joint_gaze_rt_irt | R Documentation |
Plot a joint gaze-response-time IRT fit
## S3 method for class 'eye_joint_gaze_rt_irt'
plot(x, type = c("latent", "components"), ...)
x |
Object to print, plot, summarize, or audit. |
type |
Plot or result type. |
... |
Additional arguments passed to the selected model, engine, or method. |
Invisibly returns the plotting result when available; the primary effect is drawing plot a joint gaze-response-time IRT fit.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.