View source: R/053-process-irt-plots-0-7.R
| plot.eye_joint_graded_rt_process_irt | R Documentation |
Plot a graded response + RT/process fit
## S3 method for class 'eye_joint_graded_rt_process_irt'
plot(x, ...)
x |
Object to print, plot, summarize, or audit. |
... |
Additional arguments passed to the selected model, engine, or method. |
Invisibly returns the plotting result when available; the primary effect is drawing plot a graded response + RT/process fit.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.