View source: R/067-advanced-sensitivity-diagnostics-0-8.R
| plot.eye_nonparametric_rasch_audit | R Documentation |
Plot nonparametric rasch audit diagnostics
## S3 method for class 'eye_nonparametric_rasch_audit'
plot(x, method = names(x$tests)[1L], ...)
x |
Object to process, inspect, compare, or plot. |
method |
Method used for the requested diagnostic or summary. |
... |
Additional arguments passed to the underlying method or helper. |
Invisibly returns the plotting result when available; the primary effect is drawing plot nonparametric rasch audit diagnostics.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.