View source: R/066-process-decision-features-0-8.R
| plot.eye_preaction_process_features | R Documentation |
Plot preaction process features diagnostics
## S3 method for class 'eye_preaction_process_features'
plot(x, feature = "pupil_mean", ...)
x |
Object to process, inspect, compare, or plot. |
feature |
Process feature to evaluate or display. |
... |
Additional arguments passed to the underlying method or helper. |
Invisibly returns the plotting result when available; the primary effect is drawing plot preaction process features diagnostics.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.