View source: R/067-advanced-sensitivity-diagnostics-0-8.R
| plot.eye_process_rasch_tree | R Documentation |
Plot process rasch tree diagnostics
## S3 method for class 'eye_process_rasch_tree'
plot(x, ...)
x |
Object to process, inspect, compare, or plot. |
... |
Additional arguments passed to the underlying method or helper. |
Invisibly returns the plotting result when available; the primary effect is drawing plot process rasch tree diagnostics.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.