S3 method supporting a research-scale eyeprocess object.
Usage
# S3 method for class 'eye_storage_benchmark'
plot(x, metric = c("write_seconds", "read_seconds",
"bytes"), ...)
Arguments
- x
Value for `x`. See the function description and relevant article for constraints.
- metric
Value for `metric`. See the function description and relevant article for constraints.
- ...
Additional arguments passed to the selected engine or method.
Value
The documented eyeprocess object, data frame, plot, report path, or adapter result.