View source: R/064-next-generation-plots-0-8.R
| plot_process_channel_ablation_delta | R Documentation |
Plot channel-ablation delta from a full/reference model
plot_process_channel_ablation_delta(
x = NULL,
table = NULL,
channel_col = "channel",
metric_col = "metric",
value_col = "value",
full_label = "full",
metric = NULL,
...
)
x |
'eye_process_channel_ablation' object or compatible table. |
table |
Optional explicit table. |
channel_col, metric_col, value_col |
Column names. |
full_label |
Full/reference channel label. |
metric |
Metric to evaluate or display. |
... |
Additional arguments passed to the underlying method or helper. |
A data frame containing plot channel-ablation delta from a full/reference model. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.