View source: R/064-next-generation-plots-0-8.R
| plot_pupil_activity_sensitivity | R Documentation |
Plot pupil activity sensitivity to window length
plot_pupil_activity_sensitivity(x, feature = "pupil_frequency_contrast", ...)
x |
'eye_pupil_frequency_stability' object. |
feature |
Feature name. |
... |
Additional arguments passed to the underlying method or helper. |
An R object containing plot pupil activity sensitivity to window length. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.