View source: R/064-next-generation-plots-0-8.R
| plot_pupil_activity_windows | R Documentation |
Plot pupil activity features across windows/groups
plot_pupil_activity_windows(x, feature = "pupil_frequency_contrast", ...)
x |
'eye_pupil_frequency_features' or 'eye_pupil_frequency_stability' object. |
feature |
Activity feature. |
... |
Additional arguments passed to the underlying method or helper. |
An R object containing plot pupil activity features across windows/groups. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.