View source: R/064-next-generation-plots-0-8.R
| plot_pupil_band_power | R Documentation |
Plot pupil low/high-band power summaries
plot_pupil_band_power(x, ...)
x |
'eye_pupil_frequency_features' object. |
... |
Additional arguments passed to the underlying method or helper. |
An R object containing plot pupil low/high-band power summaries. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.