View source: R/064-next-generation-plots-0-8.R
| plot_pupil_components | R Documentation |
Plot tonic/phasic pupil components
plot_pupil_components(
data,
time = "time_ms",
smoothed = "pupil_smoothed",
tonic = "pupil_tonic",
phasic = "pupil_phasic",
...
)
data |
Data frame containing the required process variables. |
time |
Time values or name of the time variable. |
smoothed |
Name of the smoothed pupil-signal column. |
tonic |
Name of the tonic pupil-component column. |
phasic |
Name of the phasic pupil-component column. |
... |
Additional arguments passed to the underlying method or helper. |
A tabular R object containing plot tonic/phasic pupil components; rows represent analysis units and columns contain the returned quantities.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.