View source: R/064-next-generation-plots-0-8.R
| plot_pupil_preprocessing_audit | R Documentation |
Plot raw-to-processed pupil preprocessing stages
plot_pupil_preprocessing_audit(
data,
time = "time_ms",
signals = c("pupil_raw", "pupil_interpolated", "pupil_smoothed", "pupil_bc"),
...
)
data |
Sample-level data. |
time |
Time column. |
signals |
Signal columns to overlay. |
... |
Additional arguments passed to the underlying method or helper. |
A tabular R object containing plot raw-to-processed pupil preprocessing stages; rows represent analysis units and columns contain the returned quantities.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.