View source: R/064-next-generation-plots-0-8.R
| plot_pupil_spectrum | R Documentation |
Plot a pupil-signal power spectrum
plot_pupil_spectrum(signal, sampling_rate_hz, max_hz = sampling_rate_hz/2, ...)
signal |
Numeric pupil signal. |
sampling_rate_hz |
Sampling rate. |
max_hz |
Maximum frequency shown; defaults to Nyquist. |
... |
Additional arguments passed to the underlying method or helper. |
A data frame containing plot a pupil-signal power spectrum. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.