Skip to contents

Part of the research-scale validation, advanced-model, interoperability, storage, adapter, or reproducibility programme. Experimental model functions remain subject to declared evidence gates.

Usage

plot_sbc_rank(x, parameter = NULL, bins = 10L, engine = c("auto", "ggplot2", "base"),
  ...)

Arguments

x

Validation collection or draw data frame.

parameter

Optional parameter.

bins

Number of bins.

engine

Plot engine.

...

Additional plotting arguments.

Value

The documented eyeprocess object, data frame, plot, report path, or adapter result.