View source: R/054-additional-process-measurement-0-7.R
| predict.eye_censored_normal_process_irt | R Documentation |
Predict expected bounded response from a censored-normal process IRT fit
## S3 method for class 'eye_censored_normal_process_irt'
predict(object, theta = object$theta, items = NULL, ...)
object |
A fitted eyeprocess model or audit object. |
theta |
Latent-trait values. |
items |
Items to include. |
... |
Additional arguments passed to the selected model, engine, or method. |
A vector or matrix containing expected bounded response from a censored-normal process IRT fit, with shape determined by the supplied analysis units.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.