View source: R/060-process-window-representations-0-8.R
| predict_aoi_trajectory | R Documentation |
Predict from an AOI growth curve
predict_aoi_trajectory(object, time = NULL)
object |
Object supplied to the S3 method. |
time |
Time values or name of the time variable. |
A data frame containing from an AOI growth curve. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.