View source: R/062-context-process-structure-0-8.R
| predict_item_parameter_priors | R Documentation |
Predict pre-pilot item-parameter priors
predict_item_parameter_priors(object, newdata)
object |
Seed model. |
newdata |
Candidate item feature data. |
An R object containing pre-pilot item-parameter priors. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.