View source: R/065-frontier-gates-0-8.R
| print.eye_gated_process_model | R Documentation |
Print a gated process model object
## S3 method for class 'eye_gated_process_model'
print(x, ...)
x |
Object to process, inspect, compare, or plot. |
... |
Additional arguments passed to the underlying method or helper. |
Invisibly returns the input object after printing its summary; the object's class and contents are unchanged.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.