View source: R/049-multimodal-irt-registry.R
| print.eye_irt_model_spec | R Documentation |
Print a multimodal IRT model specification
## S3 method for class 'eye_irt_model_spec'
print(x, ...)
x |
Object to print, plot, summarize, or audit. |
... |
Additional arguments passed to the selected model, engine, or method. |
Invisibly returns the input object after printing its summary; the object's class and contents are unchanged.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.