View source: R/062-context-process-structure-0-8.R
| print.eye_visual_context_registry | R Documentation |
Print a visual context registry object
## S3 method for class 'eye_visual_context_registry'
print(x, ...)
x |
Object to process, inspect, compare, or plot. |
... |
Additional arguments passed to the underlying method or helper. |
Invisibly returns the input object after printing its summary; the object's class and contents are unchanged.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.