View source: R/058-process-preflight-governance-0-8.R
| process_anomaly_distance | R Documentation |
Extract multivariate process anomaly distances
process_anomaly_distance(x)
x |
Object to process, inspect, compare, or plot. |
An R object containing multivariate process anomaly distances. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.