View source: R/051-advanced-process-irt-0-7.R
| process_dif_nuisance_surrogate | R Documentation |
Construct a process-data nuisance surrogate for DIF analysis
process_dif_nuisance_surrogate(
data,
process_features,
person = "participant_id",
aggregate = TRUE
)
data |
Input data frame or compatible tabular object. |
process_features |
Names of process-derived features. |
person |
Person or participant identifier column. |
aggregate |
Aggregation rule for process features. |
A data frame containing a process-data nuisance surrogate for DIF analysis. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.