View source: R/066-process-decision-features-0-8.R
| process_feature_family_registry | R Documentation |
Registry of process-feature families and interpretation guardrails
process_feature_family_registry()
A data frame containing registry of process-feature families and interpretation guardrails. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.