View source: R/066-process-decision-features-0-8.R
| process_feature_stability | R Documentation |
Summarize process-feature stability across repeated analyses
process_feature_stability(
data,
feature = "feature",
split = "split",
importance = "importance",
top_n = 20L
)
data |
Long table containing feature names and ranks/importance values. |
feature |
Feature column. |
split |
Split/resample column. |
importance |
Importance column, where larger is better. |
top_n |
Number of top features counted per split. |
A data frame containing process-feature stability across repeated analyses. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.