View source: R/074-process-registry-reliability-0-9.R
| process_icc | R Documentation |
Absolute-agreement ICC(A,1) for repeated process measures
process_icc(data, person, session, measure)
data |
Long data. |
person |
Participant column. |
session |
Session/repetition column. |
measure |
Measure column. |
A data frame containing absolute-agreement ICC(A,1) for repeated process measures. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.