View source: R/077-negative-controls-leakage-0-9.R
| process_negative_control_permute | R Documentation |
Permutation negative control
process_negative_control_permute(data, outcome, seed = 1L, within = NULL)
data |
Data frame. |
outcome |
Outcome column. |
seed |
Random seed. |
within |
Optional grouping columns within which to permute. |
An R object containing permutation negative control. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.