View source: R/077-negative-controls-leakage-0-9.R
| process_negative_control_shift | R Documentation |
Temporal-shift negative control
process_negative_control_shift(data, column, lag = 1L, by = NULL)
data |
Data frame. |
column |
Column to shift. |
lag |
Number of rows to shift within each group. |
by |
Optional grouping columns. |
An R object containing temporal-shift negative control. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.