View source: R/062-context-process-structure-0-8.R
| process_profile_summary | R Documentation |
Summarize process profiles
process_profile_summary(x)
x |
Object to process, inspect, compare, or plot. |
An R object containing process profiles. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.