View source: R/078-reproducibility-provenance-0-9.R
| provenance_edge_table | R Documentation |
Build a provenance edge table
provenance_edge_table(from, to, relation = "wasDerivedFrom")
from, to |
Node identifiers. |
relation |
PROV-like relation labels. |
A data frame containing a provenance edge table. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.