View source: R/078-reproducibility-provenance-0-9.R
| provenance_lineage_table | R Documentation |
Build a provenance lineage node table
provenance_lineage_table(
id,
type = "entity",
label = id,
value = NA_character_
)
id |
Node identifiers. |
type |
Node types such as entity, activity, agent. |
label |
Human-readable labels. |
value |
Optional values/locations. |
A data frame containing a provenance lineage node table. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.