View source: R/061-pupil-advanced-representations-0-8.R
| pupil_event_effects | R Documentation |
Extract event effects from pupil deconvolution
pupil_event_effects(x)
x |
Object to process, inspect, compare, or plot. |
An R object containing event effects from pupil deconvolution. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.