View source: R/078-reproducibility-provenance-0-9.R
| read_reproducibility_fingerprint | R Documentation |
Read a reproducibility fingerprint
read_reproducibility_fingerprint(path, format = NULL)
path |
Input path. |
format |
Optional format. |
An R object containing a reproducibility fingerprint. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.