View source: R/082-validation-evidence-programs-0-9.R
| read_validation_scenario_manifest | R Documentation |
Read a validation scenario manifest
read_validation_scenario_manifest(path)
path |
File path for reading or writing. |
An R object containing a validation scenario manifest. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.