View source: R/071-api-lifecycle-0-9.R
| register_eye_api_status | R Documentation |
Add or update API lifecycle metadata without global mutation
register_eye_api_status(
registry = eye_api_lifecycle(),
name,
status,
canonical = NA_character_,
replacement = NA_character_,
since = "0.9.0.9000",
notes = NA_character_
)
registry |
Existing lifecycle registry. |
name |
API name. |
status |
Lifecycle status. |
canonical |
Canonical API for the same concept, if applicable. |
replacement |
Replacement for deprecated/superseded API. |
since |
Version in which status applies. |
notes |
Notes. |
An R object containing add or update API lifecycle metadata without global mutation. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.