View source: R/049-multimodal-irt-registry.R
| register_irt_model | R Documentation |
Register a multimodal IRT model
register_irt_model(spec, overwrite = FALSE)
spec |
An 'irt_model_spec()'. |
overwrite |
Whether to replace an existing model with the same id. |
An R object containing a multimodal IRT model. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.