View source: R/089-irt-validation-evidence-0-9.R
| run_eyeprocess_irt_recovery | R Documentation |
When mirt is unavailable the function returns a gated result rather than a substitute estimator.
run_eyeprocess_irt_recovery(design, engine = "mirt", verbose = TRUE)
design |
Validation or simulation design object. |
engine |
Requested estimation or analysis engine. |
verbose |
Value supplied for the verbose argument. |
An object of class "eye_irt_recovery_result", stored as a named list, with components "design", "estimates", "failures", "engine". It contains iRT parameter recovery with the exact mirt engine and associated metadata or diagnostics needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.