View source: R/088-irt-engine-adapters-0-9.R
| run_eyeprocess_mirtcat | R Documentation |
Run a mirtCAT adaptive-testing workflow without fallback substitution
run_eyeprocess_mirtcat(..., engine = "mirtCAT")
... |
Additional arguments passed to the selected method or external engine. |
engine |
Requested estimation or analysis engine. |
An object of class "eye_external_irt_fit", stored as a named list, with components "status", "engine", "fit", "call". It contains a mirtCAT adaptive-testing workflow without fallback substitution and associated metadata or diagnostics needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.