View source: R/091-validation-stress-freeze-0-9.R
| run_eyeprocess_stress_evidence | R Documentation |
'corruptors' is a named list of functions accepting '(data, severity, seed)'. 'metric_fun' must return a named finite/numeric vector (NA is allowed for metrics that are undefined in a scenario). The executor records software behavior under declared corruptions and does not define universal data- quality thresholds.
run_eyeprocess_stress_evidence(data, plan, corruptors, metric_fun)
data |
Input data frame, matrix, or compatible analysis object. |
plan |
Validation or stress-evidence plan object. |
corruptors |
Named list of corruption functions used by the stress programme. |
metric_fun |
Function used to compute the stress-programme evaluation metric. |
An object of class "eye_stress_evidence_result", stored as a named list, with components "plan", "scenarios", "baseline", "results", "failures", "guardrail". It contains execute a declared measurement-stress evidence plan and associated metadata or diagnostics needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.