View source: R/063-operational-validation-0-8.R
| score_partial_response_pattern | R Documentation |
Score a partial response pattern from a calibrated mirt model
score_partial_response_pattern(
model,
response_pattern,
method = c("MAP", "EAP"),
...
)
model |
Calibrated 'mirt' model. |
response_pattern |
Full-length response vector with future/unobserved items as NA. |
method |
mirt scoring method, typically MAP or EAP. |
... |
Passed to 'mirt::fscores()'. |
A data frame containing a partial response pattern from a calibrated mirt model. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.