View source: R/072-sensitivity-multiverse-0-9.R
| sensitivity_branch_fingerprint | R Documentation |
Stable fingerprint of a sensitivity branch
sensitivity_branch_fingerprint(specification)
specification |
One-row specification table or named list. |
An R object containing stable fingerprint of a sensitivity branch. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.