View source: R/072-sensitivity-multiverse-0-9.R
| sensitivity_rank_stability | R Documentation |
Rank stability across specifications
sensitivity_rank_stability(x, id = NULL, rank = NULL, specification = NULL)
x |
Data frame or list of ranking vectors. |
id |
Optional item identifier when x is a long data frame. |
rank |
Optional rank/value column when x is a long data frame. |
specification |
Optional specification column. |
An R object containing rank stability across specifications. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.