Skip to contents

Rank stability across specifications

Usage

sensitivity_rank_stability(x, id = NULL, rank = NULL, specification = NULL)

Arguments

x

Data frame or list of ranking vectors.

id

Optional item identifier when x is a long data frame.

rank

Optional rank/value column when x is a long data frame.

specification

Optional specification column.