View source: R/055-requested-api-completion-0-7.R
| simulate_from_model | R Documentation |
Simulate data from a model or registered model specification
simulate_from_model(model, ...)
model |
Registered model id/specification, simulation function, or an object exposing a 'simulate_fun' function. |
... |
Arguments passed to the simulator. |
An R object containing data from a model or registered model specification. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.