View source: R/079-software-paper-evidence-0-9.R
| software_paper_claim_matrix | R Documentation |
Create or normalize a software-paper claim matrix
software_paper_claim_matrix(
claim,
evidence_id = NA_character_,
evidence_type = NA_character_,
status = "pending",
scope = NA_character_,
source = NA_character_
)
claim |
Claim text. |
evidence_id |
Evidence identifiers. |
evidence_type |
Evidence type. |
status |
Status such as supported, qualified, pending, or unsupported. |
scope |
Explicit scope/qualification. |
source |
Optional source/location. |
A data frame containing or normalize a software-paper claim matrix. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.