View source: R/079-software-paper-evidence-0-9.R
| software_paper_validation_table | R Documentation |
Summarise validation evidence for a software paper
software_paper_validation_table(x)
x |
Validation result/evidence matrix/table. |
An R object containing validation evidence for a software paper. The concrete class and structure follow the selected method, engine, or input object and are preserved as documented by that workflow.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.