View source: R/052-irt-validation-0-7.R
| stress_test_latent_distribution | R Documentation |
Stress test latent distribution
stress_test_latent_distribution(runner, replications = 50L, seed = 20260808L)
runner |
Function that executes one stress-test scenario. |
replications |
Number of simulation or validation replications. |
seed |
Random-number seed. |
An object of class "eye_irt_stress_test", "data.frame", stored as a data frame, containing stress test latent distribution and associated metadata needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.