View source: R/075-benchmark-stress-0-9.R
| stress_test_process_pipeline | R Documentation |
Stress-test an analysis under explicit synthetic corruptions
stress_test_process_pipeline(
data,
plans,
analysis_fun,
metric_fun = .ep09_default_sensitivity_extract,
...
)
data |
Baseline data. |
plans |
List of corruption plans. |
analysis_fun |
Function '(data, plan)'. |
metric_fun |
Function '(analysis_result, plan)' returning scalar/list/data.frame metrics. |
... |
Passed to 'apply_synthetic_corruption()'. |
An object of class "eye_process_stress_test", stored as a named list, with components "plans", "results", "baseline_hash", "created_at", "caveat". It contains stress-test an analysis under explicit synthetic corruptions and associated metadata or diagnostics needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.