View source: R/052-irt-validation-0-7.R
| stress_test_speededness | R Documentation |
Stress test speededness
stress_test_speededness(
runner,
proportions = c(0, 0.1, 0.25, 0.4),
replications = 50L,
seed = 20260808L
)
runner |
Function that executes one stress-test scenario. |
proportions |
Speededness proportions to evaluate. |
replications |
Number of simulation or validation replications. |
seed |
Random-number seed. |
An object of class "eye_irt_stress_test", "data.frame", stored as a data frame, containing stress test speededness and associated metadata needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.