View source: R/075-benchmark-stress-0-9.R
| stress_tolerance_frontier | R Documentation |
Identify the empirical stress frontier for a metric
stress_tolerance_frontier(x, severity, metric, acceptable)
x |
Stress-test result. |
severity |
Numeric corruption/severity column. |
metric |
Metric column. |
acceptable |
Function returning TRUE/FALSE for metric values. |
A data frame containing the empirical stress frontier for a metric. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.