View source: R/063-operational-validation-0-8.R
| summary.eye_validation_bundle | R Documentation |
Summarize a validation bundle object
## S3 method for class 'eye_validation_bundle'
summary(object, ...)
object |
Object supplied to the S3 method. |
... |
Additional arguments passed to the underlying method or helper. |
A named list with components "model_name", "manifest", "report", containing a validation bundle object and associated metadata or diagnostics.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.