View source: R/023-validation-orchestration.R
| summary.eye_validation_job_plan | R Documentation |
S3 method supporting a research-scale eyeprocess object.
## S3 method for class 'eye_validation_job_plan'
summary(object, ...)
object |
Value for 'object'. See the function description and relevant article for constraints. |
... |
Additional arguments passed to the selected engine or method. |
The documented eyeprocess object, data frame, plot, report path, or adapter result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.