View source: R/063-operational-validation-0-8.R
| update_person_score | R Documentation |
Update a partial person score with one new response
update_person_score(
model,
current_pattern,
item_position,
response,
method = c("MAP", "EAP"),
...
)
model |
Calibrated model. |
current_pattern |
Existing full-length partial pattern. |
item_position |
Item receiving the new response. |
response |
New response. |
method |
Scoring method. |
... |
Additional arguments passed to the underlying method or helper. |
A named list with components "pattern", "score", containing update a partial person score with one new response and associated metadata or diagnostics.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.