View source: R/069-validation-program-0-9.R
| validate_against_reference | R Documentation |
Compare a validation result with a frozen reference
validate_against_reference(x, reference, tolerance = 1e-06)
x |
Validation result. |
reference |
Frozen reference object or RDS path. |
tolerance |
Numeric tolerance for matched summary values. |
An object of class "eye_validation_reference_comparison", stored as a named list, with components "table", "tolerance", "pass", "reference_hash", "current_hash". It contains a validation result with a frozen reference and associated metadata or diagnostics needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.