View source: R/049-multimodal-irt-registry.R
| validate_irt_model | R Documentation |
Validate a registered multimodal IRT model
validate_irt_model(spec, validation = NULL, ...)
spec |
IRT model or validation specification. |
validation |
Validation results or validation specification. |
... |
Additional arguments passed to the selected model, engine, or method. |
An object of class "eye_irt_evidence_grade", stored as a named list, with components "model_id", "grade", "checks", "recovery", "contract", "warning". It contains a registered multimodal IRT model and associated metadata or diagnostics needed to interpret the result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.