View source: R/063-operational-validation-0-8.R
| validation_bundle_manifest | R Documentation |
Create a machine-readable validation manifest
validation_bundle_manifest(x)
x |
Object to process, inspect, compare, or plot. |
A data frame containing a machine-readable validation manifest. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.