View source: R/069-validation-program-0-9.R
| validation_condition_ranking | R Documentation |
Rank validation conditions by a transparent robustness score
validation_condition_ranking(
x,
weights = c(rmse = 1, abs_bias = 1, coverage_error = 1, failure_rate = 1)
)
x |
Validation result. |
weights |
Named weights for rmse, absolute bias, coverage error, and failure rate. |
A tabular R object containing rank validation conditions by a transparent robustness score; rows represent analysis units and columns contain the returned quantities.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.