View source: R/052-irt-validation-0-7.R
| validation_failure_taxonomy | R Documentation |
Classify common estimator failures without hiding the original message
validation_failure_taxonomy(x)
x |
Error/condition/message vector. |
A data frame containing classify common estimator failures without hiding the original message. Rows represent the analysis units and columns contain the identifiers, estimates, or diagnostics defined by the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.