View source: R/091-validation-stress-freeze-0-9.R
| verify_eyeprocess_validation_evidence | R Documentation |
Verify the integrity hash of a frozen evidence bundle
verify_eyeprocess_validation_evidence(x)
x |
Object to validate, summarize, verify, or otherwise process. |
A logical value or vector indicating verify the integrity hash of a frozen evidence bundle.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.